'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _backbone = require('backbone');

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _VerifiedMod = require('../models/VerifiedMod');

var _VerifiedMod2 = _interopRequireDefault(_VerifiedMod);

var _serverConnect = require('../utils/serverConnect');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _class = function (_Collection) {
  _inherits(_class, _Collection);

  function _class() {
    var _ref;

    _classCallCheck(this, _class);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var _this = _possibleConstructorReturn(this, (_ref = _class.__proto__ || Object.getPrototypeOf(_class)).call.apply(_ref, [this].concat(args)));

    _this._data = {};
    return _this;
  }

  _createClass(_class, [{
    key: 'model',
    value: function model(attrs, options) {
      return new _VerifiedMod2.default(attrs, options);
    }
  }, {
    key: 'modelId',
    value: function modelId(attrs) {
      return attrs.peerID;
    }
  }, {
    key: 'url',
    value: function url() {
      var usingTor = (0, _serverConnect.getCurrentConnection)().server.get('useTor');
      return _app2.default.localSettings.get('verifiedModsProvider' + (usingTor ? 'Tor' : ''));
    }
  }, {
    key: 'matched',


    /**
     * Return a list of verified moderators that match the ids passed in
     * @param IDs {array} - a list of IDs
     */
    value: function matched() {
      var IDs = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

      return this.filter(function (mod) {
        return IDs.includes(mod.get('peerID'));
      });
    }

    /**
     * Return a badge object to use to represent the verified moderators available on a listing.
     * If none of the moderators have a badge value, return the local badge files.
     * @param IDs {array} - a list of IDs
     */

  }, {
    key: 'defaultBadge',
    value: function defaultBadge(IDs) {
      var modelWithBadge = _underscore2.default.find(this.matched(IDs), function (mod) {
        return mod.get('type').badge;
      });
      return _extends({}, this.localBadge, modelWithBadge && modelWithBadge.get('type').badge || {});
    }
  }, {
    key: 'parse',
    value: function parse(response) {
      /* The data is expected to be delivered in the following format. There must be at least one
         type with a badge, or the grey loading badge will be shown instead.
      {
        data: {
          name: 'name of provider (required)',
          description: 'description of the provider (optional)',
          link: 'url to the provider (required)'
        },
        types: [
          {
            name: 'standard (required)',
            description: 'description of this type of moderator (optional)',
            badge: {
              large: "url",
              medium: "url",
              small: "url",
              tiny: "url"
            }
          }
        ],
        moderators: [
          {
            peerID: 'QmVFNEj1rv2d3ZqSwhQZW2KT4zsext4cAMsTZRt5dAQqFJ',
            type: 'standard'
          }
        ]
      }
       */
      this._data = response.data || {};
      this._data.url = this.url(); // backup for templates if the link is missing
      var parsedMods = response.moderators ? response.moderators : [];
      /*
         Embed the type in each moderator so it's easier to use elsewhere. It should look like:
         peerID: string,
         type: {
           name: string,
           description: string,
           badge: url string,
           }
       */
      var parsedResponse = [];
      parsedMods.forEach(function (mod) {
        if (response.types && response.types.length && mod.type) {
          mod.type = _underscore2.default.findWhere(response.types, { name: mod.type });
          if (mod.type) parsedResponse.push(mod);
        }
      });
      return parsedResponse;
    }
  }, {
    key: 'data',
    get: function get() {
      return this._data;
    }
  }, {
    key: 'localBadge',
    get: function get() {
      return {
        large: '../imgs/verifiedModeratorBadge-large.png',
        medium: '../imgs/verifiedModeratorBadge-medium.png',
        small: '../imgs/verifiedModeratorBadge-small.png',
        tiny: '../imgs/verifiedModeratorBadge-tiny.png'
      };
    }
  }]);

  return _class;
}(_backbone.Collection);

exports.default = _class;