'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTranslatedRegions = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.getIndexedRegions = getIndexedRegions;

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _countries = require('./countries');

var _countries2 = _interopRequireDefault(_countries);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var euCountries = ['AUSTRIA', 'BELGIUM', 'BULGARIA', 'CROATIA', 'CYPRUS', 'CZECH_REPUBLIC', 'DENMARK', 'ESTONIA', 'FINLAND', 'FRANCE', 'GERMANY', 'GREECE', 'HUNGARY', 'IRELAND', 'ITALY', 'LATVIA', 'LITHUANIA', 'LUXEMBOURG', 'MALTA', 'NETHERLANDS', 'POLAND', 'PORTUGAL', 'ROMANIA', 'SLOVAKIA', 'SLOVENIA', 'SPAIN', 'SWEDEN', 'UNITED_KINGDOM'];

var regions = [{
  id: 'ALL',
  countries: [].concat(_toConsumableArray(_countries2.default.map(function (country) {
    return country.dataName;
  })))
}, {
  id: 'EUROPEAN_UNION',
  countries: euCountries
}, {
  id: 'EUROPEAN_ECONOMIC_AREA',
  countries: [].concat(euCountries, ['ICELAND', 'LIECHTENSTEIN', 'NORWAY'])
}];

exports.default = regions;


var indexedRegions = void 0;

function getIndexedRegions() {
  if (indexedRegions) return indexedRegions;

  indexedRegions = regions.reduce(function (indexedObj, region) {
    indexedObj[region.id] = _underscore2.default.omit(region, 'id');
    return indexedObj;
  }, {});

  return indexedRegions;
}

function getTranslatedRegions() {
  var lang = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _app2.default.localSettings.standardizedTranslatedLang();
  var sort = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

  if (!lang) {
    throw new Error('Please provide the language the translated regions' + ' should be returned in.');
  }

  var translated = regions.map(function (region) {
    return _extends({}, region, {
      name: _app2.default.polyglot.t('regions.' + region.id)
    });
  });

  if (sort) {
    translated = translated.sort(function (a, b) {
      return a.name.localeCompare(b.name, lang);
    });
  }

  return translated;
}

var memoizedGetTranslatedRegions = _underscore2.default.memoize(getTranslatedRegions, function (lang, sort) {
  return lang + '-' + !!sort;
});

exports.getTranslatedRegions = memoizedGetTranslatedRegions;