'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

exports.processMessage = processMessage;

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _is_js = require('is_js');

var _is_js2 = _interopRequireDefault(_is_js);

var _emojis = require('../../data/emojis');

var _sanitizeHtml = require('sanitize-html');

var _sanitizeHtml2 = _interopRequireDefault(_sanitizeHtml);

var _twemoji = require('twemoji');

var _twemoji2 = _interopRequireDefault(_twemoji);

var _app = require('../../app');

var _app2 = _interopRequireDefault(_app);

var _BaseModel2 = require('../BaseModel');

var _BaseModel3 = _interopRequireDefault(_BaseModel2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Will return a processed chat messages with changes appropriate for the UI (e.g. emojis will be
 * twemojified, ob urls will be turned into links, etc...).
 */
function processMessage(message) {
  if (typeof message !== 'string') {
    throw new Error('Please provide a message as a string.');
  }

  var processedMessage = message;

  // jquery's html function converts &'s to &amps which messes with some of our
  // string replacements, particulary when the &amps are in an ob link. So, we'll
  // replace them with something else and then replace them back later.
  processedMessage = processedMessage.replace(/&amp;/g, '__ob-full-amp__').replace(/&/g, '__ob-compact-amp__');

  var $message = (0, _jquery2.default)('<div>' + processedMessage + '</div>');
  var anchors = [];

  // Ensure any OB links, handles (must be @ prefaced) or GUIDS are turned into anchor tags.

  // First we'll pull out any existing anchors and set them aside since we want to
  // leave those alone (i.e. avoid wrapping a guid / handle that's already in an anchor in
  // another one).
  $message.find('a').each(function (index, el) {
    anchors.push(el);
    (0, _jquery2.default)(el).replaceWith((0, _jquery2.default)('<div />').addClass('__ob-replaced-anchor__'));
  });

  var wordsToAnchorify = [];
  var findWords = function findWords(node) {
    if (node.nodeType === 3) {
      // It's a text node. Loop through each word and if it's a guid or handle we keep track of it
      // so later we'll wrap it in an anchor element.
      node.textContent.replace(/\r\n/g, ' ').replace('\n', ' ').match(/\S+\s*/g).forEach(function (word) {
        var w = word.trim();
        if (wordsToAnchorify.includes(w)) return;

        if (w.startsWith('@') && w.length > 1 || w.startsWith('ob://') && w.length > 5 || w.startsWith('http://') && w.length >= 11 || w.startsWith('https://') && w.length >= 12 || w.startsWith('www.') && w.length >= 8) {
          wordsToAnchorify.push(w);
        }
      });
    } else {
      node.childNodes.forEach(function (child) {
        return findWords(child);
      });
    }
  };

  findWords($message[0]);

  processedMessage = $message.html();

  wordsToAnchorify.forEach(function (word) {
    var href = !_is_js2.default.url(word) && !word.startsWith('ob://') ? '#ob://' + word : word;

    if (_is_js2.default.url(word)) {
      var link = document.createElement('a');
      link.setAttribute('href', word);
      if (link.protocol === 'file:') {
        href = 'http://' + word;
      }
    }

    processedMessage = processedMessage.split(word).join('<a href="' + href + '" class="clrTEm">' + word + '</a>');
  });

  // restore the anchors we pulled out earlier
  $message = (0, _jquery2.default)('<div>' + processedMessage + '</div>');
  $message.find('.__ob-replaced-anchor__').each(function (index, el) {
    (0, _jquery2.default)(el).replaceWith((0, _jquery2.default)(anchors[index]).addClass('clrTEm'));
  });

  processedMessage = $message.html().replace(/__ob-full-amp__/g, '&amp;').replace(/__ob-compact-amp__/g, '&');

  // convert any unicode emoji characters to images via Twemoji
  processedMessage = _twemoji2.default.parse(processedMessage, function (icon) {
    return '../imgs/emojis/72X72/' + icon + '.png';
  });

  return processedMessage;
}

var ChatMessage = function (_BaseModel) {
  _inherits(ChatMessage, _BaseModel);

  function ChatMessage() {
    _classCallCheck(this, ChatMessage);

    return _possibleConstructorReturn(this, (ChatMessage.__proto__ || Object.getPrototypeOf(ChatMessage)).apply(this, arguments));
  }

  _createClass(ChatMessage, [{
    key: 'defaults',
    value: function defaults() {
      return {
        subject: '',
        message: '',
        read: false,
        outgoing: true
      };
    }
  }, {
    key: 'url',
    value: function url() {
      return _app2.default.getServerUrl('ob/' + (this.isGroupChatMessage ? 'groupchat' : 'chat') + '/');
    }
  }, {
    key: 'set',
    value: function set(key, val) {
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      // Handle both `"key", value` and `{key: value}` -style arguments.
      var attrs = void 0;
      var opts = options;

      if ((typeof key === 'undefined' ? 'undefined' : _typeof(key)) === 'object') {
        attrs = key;
        opts = val || {};
      } else {
        (attrs = {})[key] = val;
      }

      if (typeof attrs.message === 'string') {
        // Convert any emoji placeholder (e.g :smiling_face:) into
        // emoji unicode characters.
        var emojiPlaceholderRegEx = new RegExp(':.+?:', 'g');
        var matches = attrs.message.match(emojiPlaceholderRegEx, 'g');

        if (matches) {
          matches.forEach(function (match) {
            var emoji = (0, _emojis.getEmojiByName)(match);

            if (emoji && emoji.char) {
              attrs.message = attrs.message.replace(match, emoji.char);
            }
          });
        }

        // sanitize the message
        attrs.message = (0, _sanitizeHtml2.default)(attrs.message);

        // Generate a processed message with changes to the message that are specific to our UI.
        attrs.processedMessage = processMessage(attrs.message);
      } else {
        // The processedMessage is automatically derived from the message and should not
        // be set directly.
        delete attrs.processedMessage;
      }

      return _get(ChatMessage.prototype.__proto__ || Object.getPrototypeOf(ChatMessage.prototype), 'set', this).call(this, attrs, opts);
    }
  }, {
    key: 'validate',
    value: function validate(attrs) {
      var errObj = {};
      var addError = function addError(fieldName, error) {
        errObj[fieldName] = errObj[fieldName] || [];
        errObj[fieldName].push(error);
      };

      var max = this.constructor.max;

      if (!this.isGroupChatMessage) {
        if (!attrs.peerId) {
          addError('peerId', 'The peerId is required');
        }
      } else if (!Array.isArray(attrs.peerIds) || !attrs.peerIds.length) {
        addError('peerIds', 'peerIds must be provided as an array.');
      }

      if (attrs.subject !== undefined && typeof attrs.subject !== 'string') {
        addError('subject', 'If providing a subject, it must be provided as a string.');
      } else if (attrs.subject.length > max.subjectLength) {
        addError('subject', 'The subject exceeds the max length of ' + max.subjectLength);
      } else if (this.isGroupChatMessage && !attrs.subject) {
        addError('subject', 'A subject is required for a group chat message.');
      }

      if (attrs.message.length > max.messageLength) {
        addError('message', 'The message exceeds the max length of ' + max.messageLength);
      }

      if (Object.keys(errObj).length) return errObj;

      return undefined;
    }
  }, {
    key: 'sync',
    value: function sync(method, model, options) {
      options.attrs = options.attrs || model.toJSON(options);

      if (method === 'create') {
        var timestamp = new Date().toISOString();
        options.attrs.timestamp = timestamp;
        this.set('timestamp', timestamp);
      }

      return _get(ChatMessage.prototype.__proto__ || Object.getPrototypeOf(ChatMessage.prototype), 'sync', this).call(this, method, model, options);
    }
  }, {
    key: 'idAttribute',
    get: function get() {
      return 'messageId';
    }
  }, {
    key: 'isGroupChatMessage',
    get: function get() {
      return !!this.get('peerIds');
    }
  }], [{
    key: 'max',
    get: function get() {
      return {
        subjectLength: 500,
        messageLength: 20000
      };
    }
  }]);

  return ChatMessage;
}(_BaseModel3.default);

exports.default = ChatMessage;