'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _utils = require('../../utils');

var _is_js = require('is_js');

var _is_js2 = _interopRequireDefault(_is_js);

var _app = require('../../app');

var _app2 = _interopRequireDefault(_app);

var _backbone = require('backbone');

var _BaseModel2 = require('../BaseModel');

var _BaseModel3 = _interopRequireDefault(_BaseModel2);

var _Image = require('./Image');

var _Image2 = _interopRequireDefault(_Image);

var _VariantOptions = require('../../collections/listing/VariantOptions');

var _VariantOptions2 = _interopRequireDefault(_VariantOptions);

var _Skus = require('../../collections/listing/Skus');

var _Skus2 = _interopRequireDefault(_Skus);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var ListingImages = function (_Collection) {
  _inherits(ListingImages, _Collection);

  function ListingImages() {
    _classCallCheck(this, ListingImages);

    return _possibleConstructorReturn(this, (ListingImages.__proto__ || Object.getPrototypeOf(ListingImages)).apply(this, arguments));
  }

  _createClass(ListingImages, [{
    key: 'model',
    value: function model(attrs, options) {
      return new _Image2.default(_extends({
        _clientID: attrs._clientID || (0, _utils.guid)()
      }, attrs), options);
    }
  }, {
    key: 'modelId',
    value: function modelId(attrs) {
      return attrs._clientID;
    }
  }]);

  return ListingImages;
}(_backbone.Collection);

var _class = function (_BaseModel) {
  _inherits(_class, _BaseModel);

  function _class() {
    _classCallCheck(this, _class);

    return _possibleConstructorReturn(this, (_class.__proto__ || Object.getPrototypeOf(_class)).apply(this, arguments));
  }

  _createClass(_class, [{
    key: 'defaults',
    value: function defaults() {
      return {
        title: '',
        description: '',
        tags: [],
        categories: [],
        nsfw: false,
        condition: 'NEW',
        images: new ListingImages(),
        options: new _VariantOptions2.default(),
        skus: new _Skus2.default()
      };
    }
  }, {
    key: 'validate',
    value: function validate(attrs) {
      var _this3 = this;

      var errObj = {};

      var addError = function addError(fieldName, error) {
        errObj[fieldName] = errObj[fieldName] || [];
        errObj[fieldName].push(error);
      };

      var max = this.max;

      if (!attrs.title) {
        addError('title', _app2.default.polyglot.t('itemModelErrors.provideTitle'));
      } else if (attrs.title.length > max.titleLength) {
        addError('title', _app2.default.polyglot.t('itemModelErrors.titleTooLong'));
      }

      if (this.conditionTypes.indexOf(attrs.condition) === -1) {
        addError('condition', _app2.default.polyglot.t('itemModelErrors.badConditionType'));
      }

      if (_is_js2.default.not.string(attrs.description)) {
        addError('description', 'The description must be of type string.');
      } else if (attrs.description.length > max.descriptionLength) {
        addError('description', _app2.default.polyglot.t('itemModelErrors.descriptionTooLong'));
      }

      if (attrs.price === '') {
        addError('price', _app2.default.polyglot.t('itemModelErrors.provideAmount'));
      } else if (_is_js2.default.not.number(attrs.price)) {
        addError('price', _app2.default.polyglot.t('itemModelErrors.provideNumericAmount'));
      } else if (attrs.price <= 0) {
        addError('price', _app2.default.polyglot.t('itemModelErrors.provideAmountGreaterThanZero'));
      }

      if (!attrs.images.length) {
        addError('images', _app2.default.polyglot.t('itemModelErrors.imageRequired'));
      } else if (attrs.images.length > max.images) {
        addError('images', 'The number of images cannot exceed ' + max.images);
      }

      if (attrs.tags) {
        if (_is_js2.default.array(attrs.tags)) {
          if (attrs.tags.length > max.tags) {
            addError('tags', _app2.default.polyglot.t('itemModelErrors.tooManyTags', { maxTags: max.tags }));
          }

          attrs.tags.forEach(function (tag, index) {
            if (_is_js2.default.not.string(tag)) {
              addError('tags', 'Tag at index ' + index + ' is not a string and should be.');
            } else if (tag.length > _this3.max.tagLength) {
              addError('tags', 'Tag ' + tag + ' exceeds the maximum tag length of ' + _this3.max.tagLength + '.');
            }
          });
        } else {
          addError('tags', 'Tags must be provided as an array.');
        }
      }

      if (attrs.categories && attrs.categories.length > max.cats) {
        addError('categories', _app2.default.polyglot.t('itemModelErrors.tooManyCats', { maxCats: max.cats }));
      }

      // Quantity and productId are not allowed on the Item in the listing API. Instead they are
      // accomplished via a "dummy" Sku object. Since that seems a bit klunky, out model will
      // allow them and the Listing model will do the translation in parse / sync. If this is a
      // crypto listing then item.cryptoQuantity will be created in liu of item.quantity.
      if (attrs.productId && attrs.productId.length > this.max.productIdLength) {
        addError('productId', 'The productId cannot exceed ' + this.max.productIdLength + ' characters.');
      }

      // If providing a top-level quantity or cryptoQuantity (for cryptolistings), we'll validate
      // them. Quantity should only be provided for non-crypto listings where  you are tracking
      // inventory and have no options (i.e. are not tracking inventory on the variant level).
      // cryptoQuantity is required for crypto listings.
      if (typeof attrs.quantity !== 'undefined') {
        if (typeof attrs.quantity === 'string' && !attrs.quantity) {
          addError('quantity', _app2.default.polyglot.t('itemModelErrors.provideQuantity'));
        } else if (typeof attrs.quantity !== 'number') {
          addError('quantity', _app2.default.polyglot.t('itemModelErrors.provideNumericQuantity'));
        }
      }

      if (typeof attrs.cryptoQuantity !== 'undefined') {
        if (typeof attrs.cryptoQuantity === 'string' && !attrs.cryptoQuantity) {
          addError('cryptoQuantity', _app2.default.polyglot.t('itemModelErrors.provideQuantity'));
        } else if (typeof attrs.cryptoQuantity !== 'number') {
          addError('cryptoQuantity', _app2.default.polyglot.t('itemModelErrors.provideNumericQuantity'));
        }
      }
      // END - quantity, cryptoQuantity and productId

      var maxCombos = 1;

      attrs.options.forEach(function (option) {
        return maxCombos *= option.get('variants') && option.get('variants').length || 1;
      });

      if (attrs.skus.length > maxCombos) {
        addError('skus', 'You have provided more SKUs than variant combinations.');
      }

      // ensure no SKUs with the same variantCombo
      // http://stackoverflow.com/a/24968449/632806
      var uniqueSkus = attrs.skus.map(function (sku) {
        return { count: 1, name: JSON.stringify(sku.get('variantCombo')) };
      }).reduce(function (a, b) {
        a[b.name] = (a[b.name] || 0) + b.count;
        return a;
      }, {});

      var duplicateSkus = Object.keys(uniqueSkus).filter(function (a) {
        return uniqueSkus[a] > 1;
      });

      duplicateSkus.forEach(function (dupeSku) {
        addError('skus', 'Variant combos must be unique. ' + dupeSku + ' is duplicated.');
      });

      attrs.skus.forEach(function (sku) {
        var varCombo = sku.variantCombo;

        // ensure that each SKU has a variantCombo with the correct length
        // (which is the length of the options)
        if (_is_js2.default.array(varCombo)) {
          // ensure the variantCombo actually corresponds to a provided option.variant value
          varCombo.forEach(function (val, index) {
            if (!attrs.options[index] || !attrs.options[index].variants || !attrs.options[index].variants.length || !attrs.options[index].variants[val]) {
              addError('skus', 'Invalid variant combo ' + JSON.stringify(varCombo) + '.');
            }
          });
        }
      });

      // Ensure no duplicate VariantOption names.
      var optionsNames = attrs.options.map(function (option) {
        return option.get('name');
      });
      attrs.options.forEach(function (option, index) {
        if (optionsNames.indexOf(option.get('name')) !== index) {
          addError('options[' + option.cid + '].name', _app2.default.polyglot.t('itemModelErrors.duplicateOptionName'));
        }

        // Ensure no duplicate variant names.
        var variantNames = option.get('variants').map(function (variant) {
          return variant.get('name');
        });
        option.get('variants').forEach(function (variant, vIndex) {
          if (variantNames.indexOf(variant.get('name')) !== vIndex) {
            var key = 'options[' + option.cid + '].' + ('variants[' + variant.cid + '].name');
            addError(key, _app2.default.polyglot.t('itemModelErrors.duplicateVariantName', {
              name: variant.get('name')
            }));
          }
        });
      });

      if (attrs.options.length > this.max.optionCount) {
        addError('options', _app2.default.polyglot.t('itemModelErrors.tooManyOptions', { maxOptionCount: this.max.optionCount }));
      }

      errObj = this.mergeInNestedErrors(errObj);

      if (Object.keys(errObj).length) return errObj;

      return undefined;
    }
  }, {
    key: 'nested',
    get: function get() {
      return {
        images: ListingImages,
        options: _VariantOptions2.default,
        skus: _Skus2.default
      };
    }
  }, {
    key: 'conditionTypes',
    get: function get() {
      return ['NEW', 'USED_EXCELLENT', 'USED_GOOD', 'USED_POOR', 'REFURBISHED'];
    }
  }, {
    key: 'max',
    get: function get() {
      return {
        descriptionLength: 50000,
        images: 30,
        tags: 10,
        cats: 10,
        titleLength: 140,
        tagLength: 40,
        productIdLength: 40,
        optionCount: 30
      };
    }
  }, {
    key: 'isInventoryTracked',
    get: function get() {
      var isInventoryTracked = false;

      if (this.get('options').length) {
        // If we have options and at least one has a non-infinite inventory,
        // we'll consider you to be tracking inventory
        isInventoryTracked = !!this.get('skus').find(function (sku) {
          return !sku.get('infiniteInventory');
        });
      } else {
        // If you don't have any options and have the top level as a non-negative
        // value (i.e. not infiniteInventory), we'll consider you to be tracking inventory
        isInventoryTracked = this.get('quantity') >= 0;
      }

      return isInventoryTracked;
    }
  }]);

  return _class;
}(_BaseModel3.default);

exports.default = _class;