'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.events = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.shipsFreeToMe = shipsFreeToMe;

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _app = require('../../app');

var _app2 = _interopRequireDefault(_app);

var _backbone = require('backbone');

var _Listing = require('./Listing');

var _Listing2 = _interopRequireDefault(_Listing);

var _ListingShort = require('./ListingShort');

var _ListingShort2 = _interopRequireDefault(_ListingShort);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// This is an event emitter that we will trigger listing events through.
// In many cases it is preferable to binding directly to a Listing model
// because you may not have a reference to the Listing model that has had
// some event happen, even though that model represents the same listing
// (i.e. same slug) as the one you do have a reference to.
//
// The callbacks of the events below will be passed the model that
// triggered the event as well as an options object.
//
// Available events:
// (as of now these only make sense for your own listings)
// - saved: Triggered when a listing is saved. A created flag will
//   be passed into the callback options to indicate whether this was
//   a newly created listing or an update to an existing one.
// - destroying: Called when a model delete process is being initiated.*
// - destroy: Called when a model has been successfully deleted.*
//
// * for destroying & destroy the model passed into the callback may be
//   a Listing or ListingShort model.
var events = _extends({}, _backbone.Events);

exports.events = events;

// todo: unit test me

function shipsFreeToMe(md) {
  if (!(md instanceof _Listing2.default || md instanceof _ListingShort2.default)) {
    throw new Error('Please provide a model as an instance of a Listing' + ' or ListingShort model.');
  }

  var countries = [];

  _app2.default.settings.get('shippingAddresses').forEach(function (shipAddr) {
    var country = shipAddr.get('country');
    if (country) countries.push(country);
  });

  var country = _app2.default.settings.get('country');
  if (country) countries.push(country);

  var freeShipping = void 0;

  if (md instanceof _ListingShort2.default) {
    freeShipping = md.get('freeShipping');
  } else {
    freeShipping = [];

    md.get('shippingOptions').forEach(function (shipOpt) {
      shipOpt.get('services').forEach(function (service) {
        if (service.get('price') === 0) {
          freeShipping = freeShipping.concat(shipOpt.get('regions'));
        }
      });
    });
  }

  // countries may have dupes, but it's no bother for this purpose
  return freeShipping.includes('ALL') || !!_underscore2.default.intersection(freeShipping, countries).length;
}