'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

exports.spend = spend;

var _currency = require('../../utils/currency');

var _cryptoCurrencies = require('../../data/cryptoCurrencies');

var _modalManager = require('../../utils/modalManager');

var _app = require('../../app');

var _app2 = _interopRequireDefault(_app);

var _BaseModel2 = require('../BaseModel');

var _BaseModel3 = _interopRequireDefault(_BaseModel2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Spend = function (_BaseModel) {
  _inherits(Spend, _BaseModel);

  function Spend() {
    _classCallCheck(this, Spend);

    return _possibleConstructorReturn(this, (Spend.__proto__ || Object.getPrototypeOf(Spend)).apply(this, arguments));
  }

  _createClass(Spend, [{
    key: 'url',
    value: function url() {
      return _app2.default.getServerUrl('wallet/spend/');
    }
  }, {
    key: 'defaults',
    value: function defaults() {
      return {
        feeLevel: 'NORMAL',
        memo: ''
      };
    }
  }, {
    key: 'validate',
    value: function validate(attrs) {
      var errObj = {};
      var addError = function addError(fieldName, error) {
        errObj[fieldName] = errObj[fieldName] || [];
        errObj[fieldName].push(error);
      };

      if (!attrs.address) {
        addError('address', _app2.default.polyglot.t('spendModelErrors.provideAddress'));
      } else if (typeof (0, _cryptoCurrencies.getServerCurrency)().isValidAddress === 'function' && !(0, _cryptoCurrencies.getServerCurrency)().isValidAddress(attrs.address)) {
        addError('address', _app2.default.polyglot.t('spendModelErrors.invalidAddress', { cur: (0, _cryptoCurrencies.getServerCurrency)().name }));
      }

      var exchangeRateAvailable = typeof (0, _currency.getExchangeRate)(attrs.currency) === 'number';

      if (!attrs.currency) {
        addError('currency', 'Please provide a currency.');
      } else if (!exchangeRateAvailable) {
        addError('currency', _app2.default.polyglot.t('spendModelErrors.missingExchangeRateData', {
          cur: attrs.currency,
          serverCur: (0, _cryptoCurrencies.getServerCurrency)().code
        }));
      }

      if (typeof attrs.amount !== 'number') {
        addError('amount', _app2.default.polyglot.t('spendModelErrors.provideAmountNumber'));
      } else if (attrs.amount <= 0) {
        addError('amount', _app2.default.polyglot.t('spendModelErrors.amountGreaterThanZero'));
      } else if (exchangeRateAvailable && this.amountInServerCur >= _app2.default.walletBalance.get('confirmed')) {
        addError('amount', _app2.default.polyglot.t('spendModelErrors.insufficientFunds'));
      }

      if (this.feeLevels.indexOf(attrs.feeLevel) === -1) {
        addError('feeLevel', 'The fee level must be one of [' + this.feeLevels + '].');
      }

      if (attrs.memo && typeof attrs.memo !== 'string') {
        addError('memo', 'If provided, the memo should be a string.');
      }

      if (Object.keys(errObj).length) return errObj;

      return undefined;
    }
  }, {
    key: 'sync',
    value: function sync(method, model, options) {
      options.attrs = options.attrs || this.toJSON();

      if (method === 'create' || method === 'update') {
        var amount = options.attrs.amount;

        if (options.attrs.currency !== (0, _cryptoCurrencies.getServerCurrency)().code) {
          amount = this.amountInServerCur;
        }

        options.attrs.amount = (0, _currency.decimalToInteger)(amount, (0, _cryptoCurrencies.getServerCurrency)().code);
        delete options.attrs.currency;
      }

      return _get(Spend.prototype.__proto__ || Object.getPrototypeOf(Spend.prototype), 'sync', this).call(this, method, model, options);
    }
  }, {
    key: 'parse',
    value: function parse(response) {
      var parsed = _extends({}, response);

      delete parsed.txid;
      delete parsed.amount;
      delete parsed.confirmedBalance;
      delete parsed.unconfirmedBalance;
      delete parsed.timestamp;
      return parsed;
    }
  }, {
    key: 'feeLevels',
    get: function get() {
      return ['PRIORITY', 'NORMAL', 'ECONOMIC'];
    }
  }, {
    key: 'amountInServerCur',
    get: function get() {
      var cryptoAmount = 0;
      var amount = this.get('amount');

      if (typeof amount === 'number') {
        cryptoAmount = (0, _currency.convertCurrency)(amount, this.get('currency'), (0, _cryptoCurrencies.getServerCurrency)().code);
      }

      return cryptoAmount;
    }
  }]);

  return Spend;
}(_BaseModel3.default);

exports.default = Spend;

/**
 * Use this function anytime you want to spend money from the internal wallet.
 * This function will ensure the balance is properly updated and the Wallet view
 * is informed so that it's UI could reflect the transaction.
 * @param {Object} fields An object containing the arguments to the spend call -
 * (address, amount and optionally currency, memo and feeLevel).
 * @returns {Object} The jqXhr representing the POST call to the server.
 */

function spend(fields) {
  var attrs = _extends({
    currency: _app2.default && _app2.default.settings && _app2.default.settings.get('localCurrency') || 'BTC',
    feeLevel: _app2.default && _app2.default.localSettings && _app2.default.localSettings.get('defaultTransactionFee') || 'PRIORITY',
    memo: ''
  }, fields);

  var spendModel = new Spend(attrs);
  var save = spendModel.save();

  if (!save) {
    Object.keys(spendModel.validationError).forEach(function (errorKey) {
      throw new Error(errorKey + ': ' + spendModel.validationError[errorKey][0]);
    });
  } else {
    save.done(function (data) {
      if (_app2.default.walletBalance) {
        _app2.default.walletBalance.set(_app2.default.walletBalance.parse({
          confirmed: data.confirmedBalance,
          unconfirmed: data.unconfirmedBalance
        }));
      }

      var wallet = (0, _modalManager.getWallet)();

      if (wallet && wallet.onSpendSuccess) {
        wallet.onSpendSuccess(_extends({
          address: spendModel.get('address')
        }, data));
      }
    });
  }

  return save;
}