'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fixLinuxZoomIssue = fixLinuxZoomIssue;
exports.handleServerShutdownRequests = handleServerShutdownRequests;

var _electron = require('electron');

var _os = require('os');

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _selectors = require('../utils/selectors');

var _serverConnect = require('../utils/serverConnect');

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Putting start-up related one offs here that are too small for their own module and
// aren't appropriate to be in any existing module

function fixLinuxZoomIssue() {
  // fix zoom issue on Linux hiDPI
  if (process.platform === 'linux') {
    var scaleFactor = _electron.screen.getPrimaryDisplay().scaleFactor;

    if (scaleFactor === 0) {
      scaleFactor = 1;
    }

    (0, _selectors.getBody)().css('zoom', 1 / scaleFactor);
  }
}

/**
 * This function will accept requests from the main process to shutdown the OB server daemon.
 * This should only be called on the bundled app on windows. For Linux and OSX, the localServer
 * module is able to shut down the daemon via OS signals.
 */
function handleServerShutdownRequests() {
  _electron.ipcRenderer.on('server-shutdown', function () {
    if ((0, _os.platform)() !== 'win32') {
      _electron.ipcRenderer.send('server-shutdown-fail', { reason: 'Not on windows. Use childProcess.kill instead.' });
      return;
    }

    var curConn = (0, _serverConnect.getCurrentConnection)();

    if (!curConn || curConn.status !== 'connected') {
      _electron.ipcRenderer.send('server-shutdown-fail', { reason: 'No server connection' });
      return;
    }

    try {
      _jquery2.default.post(_app2.default.getServerUrl('ob/shutdown/')).fail(function (xhr) {
        return _electron.ipcRenderer.send('server-shutdown-fail', {
          xhr: xhr,
          reason: xhr && xhr.responseJSON && xhr.responseJSON.reason || ''
        });
      });
    } catch (e) {
      _electron.ipcRenderer.send('server-shutdown-fail', { reason: e.toString() });
      return;
    }
  });
}