'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function () {
  var statusMessages = {};

  _listing.events.on('destroying', function (model, opts) {
    if (statusMessages[opts.slug]) return;

    var statusMessage = _app2.default.statusBar.pushMessage({
      msg: _app2.default.polyglot.t('listingDelete.deletingListing', { listing: '<em>' + getTitle(model) + '</em>' }),
      duration: 99999999999
    });

    statusMessages[opts.slug] = statusMessage;

    opts.xhr.done(function () {
      statusMessage.update(_app2.default.polyglot.t('listingDelete.deletedListing', { listing: '<em>' + getTitle(model) + '</em>' }));

      setTimeout(function () {
        return statusMessage.remove();
      }, 3000);
    }).fail(function (xhr) {
      var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';

      var dialogBody = void 0;

      if (!failReason) {
        dialogBody = _app2.default.polyglot.t('listingDelete.deletedFailedDialogBody', { listing: '<em>' + getTitle(model) + '</em>' });
      } else if (xhr.status === 404) {
        dialogBody = _app2.default.polyglot.t('listingDelete.deletedFailedListingNotFound', { listing: '<em>' + getTitle(model) + '</em>' });
      } else {
        dialogBody = _app2.default.polyglot.t('listingDelete.deletedFailedDialogBodyWithReason', {
          listing: '<em>' + getTitle(model) + '</em>',
          reason: '<br />' + failReason
        });
      }

      statusMessage.update({
        msg: _app2.default.polyglot.t('listingDelete.deletedFailedStatusMsg', { listing: '<em>' + getTitle(model) + '</em>' }),
        type: 'warning'
      });

      setTimeout(function () {
        return statusMessage.remove();
      }, 3000);

      var failedListingDeleteDialog = new _Dialog2.default({
        title: _app2.default.polyglot.t('listingDelete.deletedFailedDialogTitle'),
        message: dialogBody,
        buttons: [{
          text: _app2.default.polyglot.t('listingDelete.deleteFailedBtnOk'),
          fragment: 'ok'
        }]
      }).on('click-ok', function () {
        return failedListingDeleteDialog.close();
      }).render().open();
    }).always(function () {
      return delete statusMessages[opts.slug];
    });
  });
};

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _listing = require('../models/listing');

var _Listing = require('../models/listing/Listing');

var _Listing2 = _interopRequireDefault(_Listing);

var _Dialog = require('../views/modals/Dialog');

var _Dialog2 = _interopRequireDefault(_Dialog);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getTitle = function getTitle(model) {
  return (
    // Model might be a Listing or ListingShort instance.
    model instanceof _Listing2.default ? model.get('item').get('title') : model.get('title')
  );
};