'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.showUpdateStatus = showUpdateStatus;
exports.updateReady = updateReady;

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _electron = require('electron');

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _Dialog = require('../views/modals/Dialog');

var _Dialog2 = _interopRequireDefault(_Dialog);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var statusMsg = void 0;
var removeStatusMsgTimout = void 0;

function showUpdateStatus() {
  var status = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'message';

  clearTimeout(removeStatusMsgTimout);

  if (!statusMsg) {
    statusMsg = _app2.default.statusBar.pushMessage({
      msg: status,
      type: type,
      duration: 9999999999
    });
  } else {
    statusMsg.update({
      msg: status,
      type: type
    });
  }

  // updates may arrive multiple times, manually remove the message when no new message
  // arrives for 6 seconds
  removeStatusMsgTimout = setTimeout(function () {
    statusMsg.remove();
    statusMsg = null;
  }, 6000);

  return statusMsg;
}

var updateReadyDialog = void 0;

function updateReady() {
  var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  if (updateReadyDialog) updateReadyDialog.close();

  var displayData = '';
  _jquery2.default.each(opts, function (key, val) {
    displayData += '<b>' + key + ':</b> <pre style="white-space: pre-wrap">' + val + '</pre>';
  });

  updateReadyDialog = new _Dialog2.default({
    title: _app2.default.polyglot.t('update.ready.title'),
    message: _app2.default.polyglot.t('update.ready.msg') + '<br><br>' + displayData,
    messageClass: 'dialogScrollMsg',
    buttons: [{
      text: _app2.default.polyglot.t('update.cancel'),
      fragment: 'cancelInstall',
      className: 'txU'
    }, {
      text: _app2.default.polyglot.t('update.install'),
      fragment: 'installUpdate',
      className: 'btn clrP clrBAttGrad clrBrDec1 clrTOnEmph'
    }]
  }).on('click-installUpdate', function () {
    return _electron.ipcRenderer.send('installUpdate');
  }).on('click-cancelInstall', function () {
    return updateReadyDialog.close();
  }).render().open();
}