'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.events = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.block = block;
exports.unblock = unblock;
exports.isBlocked = isBlocked;
exports.isBlocking = isBlocking;
exports.isUnblocking = isUnblocking;

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _backbone = require('backbone');

var _SimpleMessage = require('../views/modals/SimpleMessage');

var _utils = require('../utils');

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var events = _extends({}, _backbone.Events);

exports.events = events;


function checkAppSettings() {
  if (!_app2.default || !(_app2.default.settings instanceof _backbone.Model)) {
    throw new Error('app.settings must be a model.');
  }

  if (!Array.isArray(_app2.default.settings.get('blockedNodes'))) {
    throw new Error('app.settings.blockedNodes must be set as an array.');
  }
}

var latestSettingsSave = void 0;
var lastSentBlockedNodes = [];
var pendingBlocks = [];
var pendingUnblocks = [];

// FYI - The extra complexity in this method is due to the fact that for the block API
// you are sending the full list rather than individual items you want to unblock / unblock
// and that gets interesting if you kick off a subsequent request while a previous is still
// pending and, for example, the previous may fail whereas the subsequent (which includes
// the block/unblock from the previous) may succeed.
function blockUnblock(_block, peerIds) {
  if (typeof _block !== 'boolean') {
    throw new Error('Please provide _block as a boolean.');
  }

  if (!(0, _utils.isMultihash)(peerIds) && !Array.isArray(peerIds)) {
    throw new Error('Either provide a single peerId as a multihash or an array of peerId ' + 'multihashes.');
  }

  if (Array.isArray(peerIds)) {
    peerIds.forEach(function (peerId) {
      if (!(0, _utils.isMultihash)(peerId)) {
        throw new Error('If providing an array of peerIds, each item must be a multihash.');
      }
    });
  }

  checkAppSettings();

  var peerIdList = typeof peerIds === 'string' ? [peerIds] : peerIds;

  if (_block && _app2.default.profile && peerIdList.includes(_app2.default.profile.id)) {
    throw new Error('You cannot block your own node.');
  }

  // de-dupe peerId list
  peerIdList = Array.from(new Set(peerIdList));

  var blockedNodes = void 0; // if _block is false, semantically this means unblockedNodes

  if (_block) {
    blockedNodes = [].concat(_toConsumableArray(latestSettingsSave && latestSettingsSave.state() === 'pending' ? lastSentBlockedNodes : _app2.default.settings.get('blockedNodes')), _toConsumableArray(peerIdList));
    pendingBlocks = [].concat(_toConsumableArray(pendingBlocks), _toConsumableArray(peerIdList));
    pendingUnblocks = pendingUnblocks.filter(function (peerId) {
      return !peerIdList.includes(peerId);
    });
  } else {
    var filterList = latestSettingsSave && latestSettingsSave.state() === 'pending' ? lastSentBlockedNodes : _app2.default.settings.get('blockedNodes');
    blockedNodes = filterList.filter(function (peerId) {
      return !peerIdList.includes(peerId);
    });
    pendingUnblocks = [].concat(_toConsumableArray(pendingUnblocks), _toConsumableArray(peerIdList));
    pendingBlocks = pendingBlocks.filter(function (peerId) {
      return !peerIdList.includes(peerId);
    });
  }

  lastSentBlockedNodes = [].concat(_toConsumableArray(blockedNodes));

  latestSettingsSave = _jquery2.default.ajax({
    type: 'PATCH',
    url: _app2.default.getServerUrl('ob/settings/'),
    data: JSON.stringify({ blockedNodes: blockedNodes }),
    dataType: 'json'
  }).done(function () {
    _app2.default.settings.set('blockedNodes', blockedNodes);
    var blocked = [];
    var unblocked = [];

    pendingBlocks = pendingBlocks.filter(function (peerId) {
      if (blockedNodes.includes(peerId)) {
        blocked.push(peerId);
        return false;
      }

      return true;
    });

    pendingUnblocks = pendingUnblocks.filter(function (peerId) {
      if (!blockedNodes.includes(peerId)) {
        unblocked.push(peerId);
        return false;
      }

      return true;
    });

    if (blocked.length) {
      events.trigger('blocked', { peerIds: blocked });
    }

    if (unblocked.length) {
      events.trigger('unblocked', { peerIds: unblocked });
    }
  }).fail(function (xhr) {
    if (latestSettingsSave && latestSettingsSave.state() === 'pending') return;

    var reason = xhr.responseJSON && xhr.responseJSON.reason || '';
    var bn = _app2.default.settings.get('blockedNodes');
    var failedBlocks = pendingBlocks.filter(function (peerId) {
      return !bn.includes(peerId);
    });
    var failedUnblocks = pendingUnblocks.filter(function (peerId) {
      return bn.includes(peerId);
    });
    pendingBlocks = [];
    pendingUnblocks = [];

    if (failedBlocks.length) {
      events.trigger('blockFail', {
        peerIds: failedBlocks,
        reason: reason
      });
    }

    if (failedUnblocks.length) {
      events.trigger('unblockFail', {
        peerIds: failedUnblocks,
        reason: reason
      });
    }

    if (failedBlocks.length || failedUnblocks.length) {
      var title = void 0;
      var body = void 0;

      if (failedBlocks.length && failedUnblocks.length) {
        title = _app2.default.polyglot.t('block.errorModal.titleUnableToBlockUnblock');
        body = _app2.default.polyglot.t('block.errorModal.blockFailedListHeading') + '<br /><br />' + ('<div class="txCtr">' + failedBlocks.join('<br />') + '</div><br />') + (_app2.default.polyglot.t('block.errorModal.unblockFailedListHeading') + '<br /><br />') + ('<div class="txCtr">' + failedUnblocks.join('<br />') + '</div>');
      } else if (failedUnblocks.length) {
        title = _app2.default.polyglot.t('block.errorModal.titleUnableToUnblock');
        body = _app2.default.polyglot.t('block.errorModal.unblockFailedListHeading') + '<br /><br />' + ('<div class="txCtr">' + failedUnblocks.join('<br />') + '</div>');
      } else {
        title = _app2.default.polyglot.t('block.errorModal.titleUnableToBlock');
        body = _app2.default.polyglot.t('block.errorModal.blockFailedListHeading') + '<br /><br />' + ('<div class="txCtr">' + failedBlocks.join('<br />') + '</div>');
      }

      if (reason) {
        body += '<br />' + _app2.default.polyglot.t('block.errorModal.reason', { reason: reason });
      }

      (0, _SimpleMessage.openSimpleMessage)(title, '', { messageHtml: body });
    }
  });

  events.trigger(_block ? 'blocking' : 'unblocking', { peerIds: peerIdList });
}

function block(peerIds) {
  blockUnblock(true, peerIds);
}

function unblock(peerIds) {
  blockUnblock(false, peerIds);
}

function isBlocked(peerId) {
  if (typeof peerId !== 'string') {
    throw new Error('Please provide a peerId as a string.');
  }

  checkAppSettings();

  return _app2.default.settings.get('blockedNodes').includes(peerId);
}

function isBlocking(peerId) {
  if (typeof peerId !== 'string') {
    throw new Error('Please provide a peerId as a string.');
  }

  checkAppSettings();

  return latestSettingsSave && latestSettingsSave.state() === 'pending' && lastSentBlockedNodes.includes(peerId) || false;
}

function isUnblocking(peerId) {
  if (typeof peerId !== 'string') {
    throw new Error('Please provide a peerId as a string.');
  }

  checkAppSettings();

  return latestSettingsSave && latestSettingsSave.state() === 'pending' && !lastSentBlockedNodes.includes(peerId) && _app2.default.settings.get('blockedNodes').includes(peerId) || false;
}