'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isScrolledIntoView = isScrolledIntoView;
exports.insertAtCursor = insertAtCursor;
exports.stripHtml = stripHtml;
exports.handleLinks = handleLinks;

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _electron = require('electron');

var _backbone = require('backbone');

var _backbone2 = _interopRequireDefault(_backbone);

var _TorExternalLinkWarning = require('../views/modals/TorExternalLinkWarning');

var _TorExternalLinkWarning2 = _interopRequireDefault(_TorExternalLinkWarning);

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// todo: check args and write unit test
// http://stackoverflow.com/a/21627295/632806
function isScrolledIntoView(element) {
  var rect = element.getBoundingClientRect();
  var top = rect.top;
  var height = rect.height;
  var el = element.parentNode;

  do {
    rect = el.getBoundingClientRect();

    if (top <= rect.bottom === false) return false;

    // Check if the element is out of view due to a container scrolling
    if (top + height <= rect.top) return false;

    el = el.parentNode;
  } while (el !== document.body);
  // Check its within the document viewport
  return top <= document.documentElement.clientHeight;
}

// http://stackoverflow.com/a/41426040/632806
function insertAtCursor(myField, myValue) {
  if (document.selection) {
    // IE support
    myField.focus();
    var sel = document.selection.createRange();
    sel.text = myValue;
  } else if (window.navigator.userAgent.indexOf('Edge') > -1) {
    // Microsoft Edge
    var startPos = myField.selectionStart;
    var endPos = myField.selectionEnd;

    myField.value = myField.value.substring(0, startPos) + myValue + myField.value.substring(endPos, myField.value.length);

    var pos = startPos + myValue.length;
    myField.focus();
    myField.setSelectionRange(pos, pos);
  } else if (myField.selectionStart || myField.selectionStart === '0') {
    // MOZILLA and others
    var _startPos = myField.selectionStart;
    var _endPos = myField.selectionEnd;
    myField.value = myField.value.substring(0, _startPos) + myValue + myField.value.substring(_endPos, myField.value.length);
  } else {
    myField.value += myValue;
  }
}

/**
 * Returns a string of text with html stripped out.
 * (https://stackoverflow.com/a/822486/632806)
 */
function stripHtml(text) {
  if (typeof text !== 'string') {
    throw new Error('Please provide text as a string.');
  }

  var el = document.createElement('div');
  el.innerHTML = text;
  return el.textContent || el.innerText || '';
}

/**
 * For most cases, this handler will be able to identify an external link because
 * it will be prefaced with an "external" protocol (e.g. http, ftp). An exception
 * to this is any user based url (e.g. www.espn.com). In that case, add a
 * 'data-open-external' attribute to the url to force it to be opened externally.
 */
function handleLinks(el) {
  (0, _jquery2.default)(el).on('click', 'a:not([data-bypass])', function (e) {
    var $a = (0, _jquery2.default)(e.target).closest('a');
    var openExternally = $a.data('openExternal') !== undefined;
    var href = $a.attr('href');

    // Anchor without href is likely being handled programatically.
    if (!href) return;

    var link = document.createElement('a');
    link.setAttribute('href', href);

    if (link.protocol !== location.protocol || openExternally) {
      if (link.protocol === 'ob:' && !openExternally) {
        _backbone2.default.history.navigate(href.slice(5), true);
      } else {
        // external link
        var activeServer = _app2.default.serverConfigs.activeServer;
        var localSettings = _app2.default.localSettings;
        var warningOptedOut = _app2.default.localSettings && localSettings.get('dontShowTorExternalLinkWarning');

        if (activeServer && activeServer.get('useTor') && !warningOptedOut) {
          var warningModal = new _TorExternalLinkWarning2.default({ url: href }).render().open();

          warningModal.on('cancelClick', function () {
            return warningModal.close();
          });
          warningModal.on('confirmClick', function () {
            _electron.shell.openExternal(link.protocol === 'file:' ? 'http://' + href : href);
            warningModal.close();
          });
        } else {
          _electron.shell.openExternal(link.protocol === 'file:' ? 'http://' + href : href);
        }
      }
    } else {
      if (!href.startsWith('#')) {
        href = '#' + href;
      }

      _backbone2.default.history.navigate(href, true);
    }

    e.preventDefault();
  });
}