'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _currency = require('../utils/currency');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// How often to fetch the rates.
var fetchInterval = 1000 * 60 * 5;

// Flag to indicate if rates have been successfully fetched at least once.
var fetchRatesTimeout = void 0;
var statusBarMsg = void 0;
var failLaterTimeout = void 0;
var removeStatusMsgTimout = void 0;
var succeedLaterTimeout = void 0;

function setRetryStatus() {
  var msg = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var statusMsgOpts = _extends({
    duration: 9999999999
  }, msg);

  if (!statusBarMsg) {
    statusBarMsg = _app2.default.statusBar.pushMessage(statusMsgOpts);
    statusBarMsg.on('clickRetry', function () {
      return (0, _currency.fetchExchangeRates)();
    });
  } else {
    statusBarMsg.update(msg);
  }

  return statusBarMsg;
}

_currency.events.on('fetching-exchange-rates', function (e) {
  if (statusBarMsg) {
    setRetryStatus({
      type: 'message',
      msg: _app2.default.polyglot.t('exchangeRatesSyncer.fetchingRatesStatusMsg')
    });
  }

  clearTimeout(fetchRatesTimeout);
  clearTimeout(succeedLaterTimeout);
  clearTimeout(removeStatusMsgTimout);
  clearTimeout(failLaterTimeout);

  e.xhr.done(function () {
    if (statusBarMsg) {
      // Defer success state, otherwise it's an odd little flicker if
      // the call came back too fast.
      succeedLaterTimeout = setTimeout(function () {
        setRetryStatus({
          type: 'message',
          msg: _app2.default.polyglot.t('exchangeRatesSyncer.fetchingRatesSuccessStatusMsg')
        });

        removeStatusMsgTimout = setTimeout(function () {
          statusBarMsg.remove();
          statusBarMsg = null;
        }, 3000);
      }, 300);
    }

    fetchRatesTimeout = setTimeout(function () {
      (0, _currency.fetchExchangeRates)();
    }, fetchInterval);
  }).fail(function () {
    var retryLink = '<a class="js-retry">' + (_app2.default.polyglot.t('exchangeRatesSyncer.fetchingRatesFailStatusMsgRetryLink') + '</a>');

    // const failMessage =
    if (statusBarMsg) {
      // If the status bar already exists, we'll delay before updating it with a failure
      // state, because if the fail happens really fast, it looks like nothing happend.
      failLaterTimeout = setTimeout(function () {
        setRetryStatus({
          type: 'warning',
          msg: _app2.default.polyglot.t('exchangeRatesSyncer.fetchingRatesFailStatusMsg', { retryLink: retryLink })
        });
      }, 300);
    } else {
      setRetryStatus({
        type: 'warning',
        msg: _app2.default.polyglot.t('exchangeRatesSyncer.fetchingRatesFailStatusMsg', { retryLink: retryLink })
      });
    }
  });
});