'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.events = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.getInventory = getInventory;
exports.isFetching = isFetching;

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _backbone = require('backbone');

var _listing = require('../models/listing/');

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var events = _extends({}, _backbone.Events);

exports.events = events;


var inventoryCache = new Map();
var cacheExpires = 1000 * 60 * 5;

// todo: put in some periodic cleanup that prevents the cache from growing too large

function checkInventoryArgs(peerId) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (typeof peerId !== 'string') {
    throw new Error('Please provide a peerId as a string.');
  }

  if (options.slug !== undefined && typeof options.slug !== 'string') {
    throw new Error('If providing a slug, it must be a string.');
  }
}

function getCache(peerId) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  checkInventoryArgs(peerId, options);
  var cacheByStore = inventoryCache.get(peerId);
  var cacheBySlug = options.slug && cacheByStore && cacheByStore[options.slug] && cacheByStore[options.slug].deferred ? cacheByStore[options.slug] : null;
  cacheByStore = cacheByStore && cacheByStore.deferred ? {
    deferred: cacheByStore.deferred,
    createdAt: cacheByStore.createdAt
  } : null;

  // ensure the caches aren't expired
  [cacheByStore, cacheBySlug].forEach(function (cache) {
    if (cache && Date.now() - cache.createdAt >= cacheExpires) {
      if (cache.deferred) {
        cache.deferred.reject({
          errCode: 'TIMED_OUT',
          error: 'The inventory fetch timed out.'
        });
      }

      if (cache === cacheByStore) {
        cacheByStore = null;
      } else {
        cacheBySlug = null;
      }
    }
  });

  return {
    cacheByStore: cacheByStore,
    cacheBySlug: cacheBySlug
  };
}

function setInventory(peerId) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  checkInventoryArgs(peerId, options);

  var slugs = options.slug ? [options.slug] : Object.keys(data);

  slugs.forEach(function (slug) {
    var curCache = inventoryCache.get(peerId) || {};
    var prevInventory = curCache[slug] && curCache[slug].inventory;
    var curInventory = options.slug ? data.inventory : data[slug].inventory;

    if (curInventory !== prevInventory) {
      if (options.slug) {
        curCache[options.slug] = _extends({}, curCache[options.slug], data);
      } else {
        Object.keys(data).forEach(function (inventorySlug) {
          curCache[inventorySlug] = _extends({}, curCache[inventorySlug], data[inventorySlug]);
        });
      }

      inventoryCache.set(peerId, curCache);

      events.trigger('inventory-change', {
        peerId: peerId,
        slug: slug,
        prevInventory: prevInventory,
        inventory: curInventory
      });
    }
  });
}

_listing.events.on('saved', function (md) {
  var flatMd = md.toJSON();

  // will only update the inventory for crypto listings since the inventory
  // is not being represented properly for non-crypto when it comes to variants.
  if (flatMd.metadata.contractType === 'CRYPTOCURRENCY') {
    var inventory = flatMd.item.cryptoQuantity;
    var curCache = inventoryCache.get(_app2.default.profile.id) || {};
    curCache = curCache[flatMd.slug];
    var deferred = curCache && curCache.deferred && curCache.deferred.state === 'pending' ? curCache.deferred : _jquery2.default.Deferred();
    var lastUpdated = new Date().toISOString();
    deferred.resolve({
      inventory: inventory
    });
    var inventoryData = _extends({}, curCache, {
      lastUpdated: lastUpdated,
      createdAt: Date.now(),
      inventory: inventory,
      deferred: deferred
    });

    setInventory(_app2.default.profile.id, inventoryData, { slug: flatMd.slug });

    // todo: would be good to also abort any existing xhr, although it's unlikely there
    // would be a pending one for your own listings since I think that comes from the db
    // and should be quick. Anyhow, it would likely require exposing the xhr in the
    // inventoryCache.
  }
});

function getInventory(peerId) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  checkInventoryArgs(peerId, options);
  var opts = _extends({
    useCache: true,
    // For crypto currency listings be sure to pass in the coinDivisibility so
    // the inventory is converted into UI readable units. If fetching the
    // inventory for an entire store, this should be passed in as an object
    // keyed by slug, e.g:
    // { zec-for-sale: 100000000, eth-for-sale: 100000000000 }
    coinDivisibility: undefined
  }, options);
  var cacheObj = opts.useCache && getCache(peerId, options);
  var deferred = _jquery2.default.Deferred();

  if (!opts.useCache || !cacheObj.cacheBySlug && !cacheObj.cacheByStore) {
    // no cached data available, need to fetch

    // for local listings do not get cached data from the server - if client
    // side cache is available, it would be used since that is updated if the
    // user updates the listing (at least via this client)
    var useCache = peerId === _app2.default.profile.id ? false : opts.useCache;

    var url = 'ob/inventory/' + peerId + (opts.slug ? '/' + opts.slug : '') + ('' + (useCache ? '?usecache=true' : ''));

    var xhr = _jquery2.default.get(_app2.default.getServerUrl(url)).done(function (data) {
      var inventoryData = {};

      if (opts.slug) {
        inventoryData = _extends({}, data, {
          inventory: typeof opts.coinDivisibility === 'number' ? data.inventory / opts.coinDivisibility : data.inventory
        });
      } else {
        Object.keys(data).forEach(function (slug) {
          inventoryData[slug] = _extends({}, data[slug], {
            inventory: _typeof(opts.coinDivisibility) === 'object' && typeof opts.coinDivisibility[slug] === 'number' ? data[slug].inventory / opts.coinDivisibility[slug] : data[slug].inventory
          });
        });
      }

      deferred.resolve(inventoryData);
      events.trigger('inventory-fetch-success', {
        peerId: peerId,
        slug: opts.slug,
        xhr: xhr,
        data: inventoryData
      });

      setInventory(peerId, inventoryData, options);
    }).fail(function (failedXhr) {
      deferred.reject({
        errCode: failedXhr.statusText === 'abort' ? 'CANCELED' : 'SERVER_ERROR',
        error: xhr.responseJSON && xhr.responseJSON.reason || '',
        statusCode: xhr.status
      });

      events.trigger('inventory-fetch-fail', {
        peerId: peerId,
        slug: opts.slug,
        xhr: xhr
      });

      // clear failed fetches from the cache
      var cache = inventoryCache.get(peerId);
      if (cache) {
        var cachedItem = cache.deferred === deferred ? cache : cache[opts.slug];
        delete cachedItem.createdAt;
        delete cachedItem.deferred;
      }
    });

    var curCache = inventoryCache.get(peerId) || {};
    var requestors = [];

    // When sending back a promise, call _getPromise() with a unique id. This will include
    // a custom abort wrapper that keeps track of which callers are tracking a request.
    // The idea is that it's important to abort request when no longer needed since these
    // are http and ipfs request that could take a while, but it's possible another view is
    // using the same request. To not have different views step on each others toes,
    // internally we will keep track of who requested a request and only cancel if all
    // requestors have canceled. (fwiw - this is all abstracted from the caller of
    // getInventory).
    deferred._getPromise = function (id) {
      requestors.push(id);
      var promise = deferred.promise();
      promise.abort = function () {
        requestors.splice(requestors.indexOf(id), 1);
        if (!requestors.length) xhr.abort();
      };
      return promise;
    };

    var data = {
      createdAt: Date.now(),
      deferred: deferred
    };

    var cacheData = _extends({}, curCache, data);

    if (opts.slug) {
      cacheData = _extends({}, curCache, _defineProperty({}, opts.slug, _extends({}, curCache[opts.slug] || {}, data)));
    }

    inventoryCache.set(peerId, cacheData);

    events.trigger('inventory-fetching', {
      peerId: peerId,
      slug: opts.slug,
      xhr: xhr
    });
  } else if (opts.slug && !cacheObj.cacheBySlug && cacheObj.cacheByStore) {
    // we want data for a slug but only have data for an entire store which
    // may or may not have that slug

    cacheObj.cacheByStore.done(function (data) {
      if (data[opts.slug]) {
        deferred.resolve(data[opts.slug]);
      } else {
        // going to mirror server behavior when inventory for a given slug is not
        // available
        deferred.reject({
          errCode: 'SERVER_ERROR',
          error: 'Could not find slug in inventory',
          statusCode: 500
        });
      }
    });
  } else {
    // we have cached data to satisfy our request
    deferred = opts.slug ? cacheObj.cacheBySlug.deferred : cacheObj.cacheByStore.deferred;
  }

  var promise = deferred._getPromise ? deferred._getPromise((0, _utils.guid)()) : deferred.promise();
  promise.abort = promise.abort || function () {};
  return promise;
}

function isFetching(peerId) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  checkInventoryArgs(peerId, options);
  var cache = inventoryCache.get(peerId);
  var fetching = cache && cache.deferred && cache.deferred.state() === 'pending' || options.slug && cache && cache[options.slug] && cache[options.slug].deferred && cache[options.slug].deferred.state() === 'pending';

  return fetching;
}