'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _electron = require('electron');

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _os = require('os');

var _backbone = require('backbone');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _child_process = require('child_process');

var _child_process2 = _interopRequireDefault(_child_process);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var LocalServer = function () {
  function LocalServer(options) {
    var _this = this;

    _classCallCheck(this, LocalServer);

    if (!options.serverPath) {
      throw new Error('Please provide a server path.');
    }

    if (!options.serverFilename) {
      throw new Error('Please provide a server filename.');
    }

    if (!options.errorLogPath) {
      throw new Error('Please provide an error log path.');
    }

    if (!options.getMainWindow || typeof options.getMainWindow !== 'function') {
      throw new Error('Please provide a function that, if available, returns a mainWindow ' + 'instance.');
    }

    _underscore2.default.extend(this, _backbone.Events);
    this.serverPath = options.serverPath;
    this.serverFilename = options.serverFilename;
    this.errorLogPath = options.errorLogPath;
    this._getMainWindow = options.getMainWindow;
    this._isRunning = false;
    this._isStopping = false;
    this._debugLog = '';
    this._lastStartCommandLineArgs = [];
    this.startAfterStop = function () {
      return _this.start.apply(_this, arguments);
    };

    _electron.ipcMain.on('server-shutdown-fail', function (e) {
      var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      if (_this.isStopping && _this.serverSubProcess) {
        var reasonInsert = data.reason ? ' (' + data.reason + ')' : '';
        var logMsg = 'The server shutdown via api request failed' + reasonInsert + '. ' + 'Will forcibly shutdown.';

        _this.log(logMsg);
        _this._forceKill();
      }
    });
  }

  _createClass(LocalServer, [{
    key: 'start',
    value: function start() {
      var _this2 = this;

      var commandLineArgs = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

      if (this.isStopping) {
        this.serverSubProcess.once('exit', function () {
          return _this2.startAfterStop(commandLineArgs);
        });
        var debugInfo = 'Attempt to start server while an existing one' + ' is the process of shutting down. Will start after shut down is complete.';
        this.log(debugInfo);
        return;
      }

      if (this.isRunning) {
        if (_underscore2.default.isEqual(commandLineArgs, this._lastStartCommandLineArgs)) {
          return;
        }

        throw new Error('A server is already running with different command line options. Please ' + 'stop that server before starting a new one.');
      }

      this._isRunning = true;
      var serverStartArgs = ['start'].concat(_toConsumableArray(commandLineArgs));

      // wire in our auth cookie
      if (global.authCookie) {
        serverStartArgs = serverStartArgs.concat(['-c', global.authCookie]);
      }

      this.log('Starting local server via \'' + serverStartArgs.join(' ') + '\'.');
      console.log('Starting local server via \'' + serverStartArgs.join(' ') + '\'.');

      this._lastStartCommandLineArgs = commandLineArgs;
      this.serverSubProcess = _child_process2.default.spawn(this.serverPath + this.serverFilename, serverStartArgs, {
        detach: false,
        cwd: this.serverPath
      });

      this.serverSubProcess.stdout.once('data', function () {
        _this2.trigger('start');
      });
      this.serverSubProcess.stdout.on('data', function (buf) {
        return _this2.obServerLog('' + buf);
      });

      this.serverSubProcess.on('error', function (err) {
        var errOutput = 'The local server child process has an error: ' + err;

        _fs2.default.appendFile(_this2.errorLogPath, errOutput, function (appendFileErr) {
          if (appendFileErr) {
            console.log('Unable to write to the error log: ' + err);
          }
        });

        _this2.log(errOutput);
      });

      this.serverSubProcess.stderr.on('data', function (buf) {
        _fs2.default.appendFile(_this2.errorLogPath, String(buf), function (err) {
          if (err) {
            console.log('Unable to write to the error log: ' + err);
          }
        });

        _this2.obServerLog('' + buf, 'STDERR');
      });

      this.serverSubProcess.on('exit', function (code, signal) {
        var logMsg = void 0;

        if (code !== null) {
          logMsg = 'Server exited with code: ' + code;
        } else {
          logMsg = 'Server exited at request of signal: ' + signal + '.';
        }

        console.log(logMsg);
        _this2.log(logMsg, 'EXIT');
        _this2._isRunning = false;
        _this2.lastCloseCode = code;
        _this2.trigger('exit', { code: code });
      });

      this.serverSubProcess.unref();

      return;
    }
  }, {
    key: '_forceKill',
    value: function _forceKill() {
      if ((0, _os.platform)() !== 'win32') {
        throw new Error('For non windows OSs, use childProcess.kill and pass in a signal.');
      }

      if (!this.isStopping) {
        throw new Error('A force kill should only be attempted if you tried stopping via this.stop ' + 'and it failed.');
      }

      if (this.serverSubProcess) {
        this.log('Forcibly shutting down the server via taskkill.');
        _child_process2.default.spawn('taskkill', ['/pid', this.serverSubProcess.pid, '/f', '/t']);
      }
    }
  }, {
    key: 'stop',
    value: function stop() {
      var _this3 = this;

      if (!this.isRunning) return;

      if (this.isStopping) {
        this.serverSubProcess.removeListener('exit', this.startAfterStop);
        return;
      }

      this._isStopping = true;
      this.serverSubProcess.once('exit', function () {
        return _this3._isStopping = false;
      });

      this.log('Shutting down server');
      console.log('Shutting down server');

      if ((0, _os.platform)() === 'darwin' || (0, _os.platform)() === 'linux') {
        this.serverSubProcess.kill('SIGINT');
      } else {
        var mw = this._getMainWindow();

        if (mw) {
          mw.webContents.send('server-shutdown');
        } else {
          this._forceKill();
        }
      }
    }
  }, {
    key: 'getServerStatus',
    value: function getServerStatus() {
      var _this4 = this;

      var commandLineArgs = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

      this.log('Starting local server in status mode.');
      console.log('Starting local server in status mode.');

      var subProcess = _child_process2.default.spawn(this.serverPath + this.serverFilename, ['status'].concat(_toConsumableArray(commandLineArgs)), {
        detach: false,
        cwd: this.serverPath
      });

      subProcess.stdout.on('data', function (buf) {
        return _this4.obServerStatusLog('' + buf);
      });

      subProcess.on('error', function (err) {
        var errOutput = 'Starting local server in status mode produced an error: ' + err;

        _fs2.default.appendFile(_this4.errorLogPath, errOutput, function (appendFileErr) {
          if (appendFileErr) {
            console.log('Unable to write to the error log: ' + err);
          }
        });

        _this4.log(errOutput);
      });

      subProcess.stderr.on('data', function (buf) {
        _fs2.default.appendFile(_this4.errorLogPath, '[OB-SERVER-STATUS] ' + String(buf), function (err) {
          if (err) {
            console.log('Unable to write to the error log: ' + err);
          }
        });

        _this4.obServerStatusLog('' + buf, 'STDERR', true);
      });

      subProcess.on('exit', function (code, signal) {
        var logMsg = void 0;

        if (code !== null) {
          var encrypted = false;
          var torAvailable = false;
          logMsg = 'Local server status mode exited with code: ' + code;

          if (code === 1) {
            _this4.trigger('getServerStatusFail', { pid: subProcess.pid });
          } else if (code === 30) {
            encrypted = true;
          } else if (code === 31) {
            encrypted = true;
            torAvailable = true;
          } else if (code === 21 || code === 11) {
            torAvailable = true;
          }

          _this4.trigger('getServerStatusSuccess', {
            pid: subProcess.pid,
            torAvailable: torAvailable,
            encrypted: encrypted
          });
        } else {
          logMsg = 'Local server status mode exited at request of signal: ' + signal + '.';
          _this4.trigger('getServerStatusFail', { pid: subProcess.pid });
        }

        console.log(logMsg);
        _this4.log(logMsg, 'EXIT');
      });

      subProcess.unref();

      return subProcess.pid;
    }
  }, {
    key: '_log',
    value: function _log(msg) {
      var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'LOCAL-SERVER';

      var newLog = '[' + type + '] ' + msg + (msg.endsWith(_os.EOL) ? '' : _os.EOL);
      this._debugLog += newLog;
      this.trigger('log', this, newLog);
    }
  }, {
    key: 'log',
    value: function log(msg) {
      if (typeof msg !== 'string') {
        throw new Error('Please provide a message.');
      }

      if (!msg) return;
      this._log(msg);
    }
  }, {
    key: 'obServerLog',
    value: function obServerLog(msg) {
      var _this5 = this;

      var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'STDOUT';
      var serverType = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '[OB-SERVER]';

      if (typeof msg !== 'string') {
        throw new Error('Please provide a message.');
      }

      if (!msg) return;
      console.log(msg);

      var msgPreface = type ? '[' + type + '] ' : '';
      msg.split(_os.EOL).forEach(function (splitMsg) {
        return _this5._log('' + msgPreface + splitMsg, serverType);
      });
    }
  }, {
    key: 'obServerStatusLog',
    value: function obServerStatusLog(msg) {
      var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'STDOUT';

      this.obServerLog(msg, type, '[OB-SERVER-STATUS]');
    }
  }, {
    key: 'isRunning',
    get: function get() {
      return this._isRunning;
    }
  }, {
    key: 'isStopping',
    get: function get() {
      return this._isStopping;
    }

    /**
     * The command line args that the server was last started with. Will default to an
     * empty array if the server has never been started this session. This only applies
     * to the server being started via start(), not the server being started in status
     * mode (via getServerStatus()).
     */

  }, {
    key: 'lastStartCommandLineArgs',
    get: function get() {
      return this._lastStartCommandLineArgs;
    }
  }, {
    key: 'debugLog',
    get: function get() {
      return this._debugLog;
    }
  }]);

  return LocalServer;
}();

exports.default = LocalServer;