'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.getAppBarBadgeCount = getAppBarBadgeCount;
exports.setAppBarBadgeCount = setAppBarBadgeCount;
exports.getUnreadNotifCount = getUnreadNotifCount;
exports.setUnreadNotifCount = setUnreadNotifCount;
exports.getUnreadChatMsgCount = getUnreadChatMsgCount;
exports.setUnreadChatMsgCount = setUnreadChatMsgCount;
exports.launchNativeNotification = launchNativeNotification;

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _electron = require('electron');

var _dom = require('./dom');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var unreadNotifCount = 0;
var unreadChatMsgCount = 0;
var appBarBadgeCount = 0; // an aggregate count of unread notifications + unread chat messages
var notifAudioEl = void 0;

function getAppBarBadgeCount() {
  return appBarBadgeCount;
}

function setAppBarBadgeCount(count) {
  if (typeof count !== 'number') {
    throw new Error('Please provide a numeric count.');
  }

  if (count !== appBarBadgeCount) {
    appBarBadgeCount = count;
    _electron.ipcRenderer.send('set-badge-count', appBarBadgeCount);
  }
}

function getUnreadNotifCount() {
  return unreadNotifCount;
}

function setUnreadNotifCount(count) {
  if (typeof count !== 'number') {
    throw new Error('Please provide a numeric count.');
  }

  if (count !== unreadNotifCount) {
    unreadNotifCount = count;
    setAppBarBadgeCount(unreadNotifCount + unreadChatMsgCount);
  }
}

function getUnreadChatMsgCount() {
  return unreadChatMsgCount;
}

function setUnreadChatMsgCount(count) {
  if (typeof count !== 'number') {
    throw new Error('Please provide a numeric count.');
  }

  if (count !== unreadChatMsgCount) {
    unreadChatMsgCount = count;
    setAppBarBadgeCount(unreadNotifCount + unreadChatMsgCount);
  }
}

function playNotifSound() {
  if (!document) {
    throw new Error('The document object needs to be available to this function.');
  }

  if (!notifAudioEl) {
    notifAudioEl = document.createElement('audio');
    notifAudioEl.setAttribute('src', '../audio/notification.mp3');
  }

  notifAudioEl.play();
}

function launchNativeNotification() {
  var notifTitle = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (options.body !== undefined && typeof options.body !== 'string') {
    throw new Error('If providing a notification body, it must be provided ' + 'as a string.');
  }

  if (typeof notifTitle !== 'string') {
    throw new Error('Please provide the notifTitle as a string.');
  }

  var notifOptions = _extends({
    silent: true
  }, _underscore2.default.omit(options || {}, 'onclick', 'onerror'), {
    body: options.body ? (0, _dom.stripHtml)(options.body) : ''
  });

  var notif = new Notification(notifTitle, notifOptions);

  if (typeof options.onclick === 'function') {
    notif.addEventListener('click', notifOptions.onclick);
  }

  if (typeof options.onerror === 'function') {
    notif.addEventListener('error', notifOptions.onerror);
  }

  playNotifSound();

  return notif;
}