'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.isHiRez = isHiRez;
exports.isLargeWidth = isLargeWidth;
exports.isSmallHeight = isSmallHeight;
exports.getAvatarBgImage = getAvatarBgImage;
exports.getListingBgImage = getListingBgImage;

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// functions for determining size and resolution of the window

function isHiRez() {
  return window.matchMedia('(-webkit-min-device-pixel-ratio: 1.5)').matches;
}

function isLargeWidth() {
  return window.matchMedia('(min-width: 1500px)').matches;
}

function isSmallHeight() {
  return window.matchMedia('(max-height: 700px)').matches;
}

function getBackgroundImage() {
  var imageHashes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var standardSize = arguments[1];
  var responsiveSize = arguments[2];
  var defaultUrl = arguments[3];

  var imageHash = '';
  var bgImageProperty = '';

  if (isHiRez() && imageHashes[responsiveSize]) {
    imageHash = imageHashes[responsiveSize];
  } else if (imageHashes[standardSize]) {
    imageHash = imageHashes[standardSize];
  }

  if (imageHash) {
    bgImageProperty = 'background-image: url(' + _app2.default.getServerUrl('ob/images/' + imageHash) + ')' + (', url(' + defaultUrl + ')');
  } else {
    bgImageProperty = 'background-image: url(' + defaultUrl + ')';
  }

  return bgImageProperty;
}

function getAvatarBgImage() {
  var avatarHashes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var opts = _extends({
    standardSize: 'tiny',
    responsiveSize: 'small',
    defaultUrl: '../imgs/defaultAvatar.png'
  }, options);

  return getBackgroundImage(avatarHashes, opts.standardSize, opts.responsiveSize, opts.defaultUrl);
}

function getListingBgImage() {
  var imageHashes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var opts = _extends({
    standardSize: 'tiny',
    responsiveSize: 'small',
    defaultUrl: '../imgs/defaultItem.png'
  }, options);

  return getBackgroundImage(imageHashes, opts.standardSize, opts.responsiveSize, opts.defaultUrl);
}