'use strict';

var _electron = require('electron');

var _homedir = require('homedir');

var _homedir2 = _interopRequireDefault(_homedir);

var _yargs = require('yargs');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _child_process = require('child_process');

var _child_process2 = _interopRequireDefault(_child_process);

var _utils = require('./js/utils');

var _localServer = require('./js/utils/localServer');

var _localServer2 = _interopRequireDefault(_localServer);

var _mainProcLocalServerEvents = require('./js/utils/mainProcLocalServerEvents');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
var mainWindow = void 0;
var trayMenu = void 0;
var closeConfirmed = false;
var version = _electron.app.getVersion();

function isOSWin64() {
  return process.arch === 'x64' || process.env.hasOwnProperty('PROCESSOR_ARCHITEW6432');
}

var plat = process.platform === 'win32' ? '' + (isOSWin64() ? 'win64' : 'win32') : process.platform;

var feedURL = 'https://updates2.openbazaar.org:5001/update/' + plat + '/' + version;

global.serverLog = '';

var handleStartupEvent = function handleStartupEvent() {
  if (process.platform !== 'win32') {
    return false;
  }

  var squirrelCommand = process.argv[1];

  function exeSquirrelCommand(args, cb) {
    var updateDotExe = _path2.default.resolve(_path2.default.dirname(process.execPath), '..', 'update.exe');
    var child = _child_process2.default.spawn(updateDotExe, args, { detached: true });
    child.on('close', cb());
  }

  function install(cb) {
    var target = _path2.default.basename(process.execPath);
    exeSquirrelCommand(['--createShortcut', target, ' --shortcut-locations=Desktop,StartMenu'], cb);
  }

  function uninstall(cb) {
    var target = _path2.default.basename(process.execPath);
    exeSquirrelCommand(['--removeShortcut', target], cb);
  }

  switch (squirrelCommand) {
    case '--squirrel-install':
      install(_electron.app.quit);
      break;

    case '--squirrel-updated':
      // Always quit when done
      _electron.app.quit();
      return true;

    case '--squirrel-uninstall':
      // Always quit when done
      uninstall(_electron.app.quit);
      return true;

    case '--squirrel-obsolete':
      // This is called on the outgoing version of your app before
      // we update to the new version - it's the opposite of
      // --squirrel-updated
      _electron.app.quit();
      return true;
    default:
      break;
  }

  return true;
};

if (handleStartupEvent()) {
  console.log('OpenBazaar started on Windows...');
}

var serverPath = '' + __dirname + _path2.default.sep + '..' + _path2.default.sep + 'openbazaar-go' + _path2.default.sep;
var serverFilename = process.platform === 'darwin' || process.platform === 'linux' ? 'openbazaard' : 'openbazaard.exe';
var isBundledApp = _fs2.default.existsSync(serverPath + serverFilename);
global.isBundledApp = isBundledApp;
var localServer = void 0;

if (isBundledApp) {
  global.localServer = localServer = new _localServer2.default({
    getMainWindow: function getMainWindow() {
      return mainWindow;
    },
    serverPath: serverPath,
    serverFilename: serverFilename,
    errorLogPath: '' + __dirname + _path2.default.sep + '..' + _path2.default.sep + '..' + _path2.default.sep + 'error.log'
    // IMPORTANT: From the main process, only bind events to the localServer instance
    // using the functions in the mainProcLocalServerEvents module. The reasons for that
    // will be explained in the module.
  });

  global.authCookie = (0, _utils.guid)();
}

var updatesSupported = process.platform === 'win32' || process.platform === 'darwin';
global.updatesSupported = updatesSupported;

// set the client data path
var defaultUserDataPath = void 0;

switch (process.platform) {
  case 'win32':
    defaultUserDataPath = (0, _homedir2.default)() + '\\OpenBazaar2.0-ClientData';
    break;
  case 'darwin':
    defaultUserDataPath = (0, _homedir2.default)() + '/Library/Application Support/OpenBazaar2.0-ClientData';
    break;
  default:
    defaultUserDataPath = (0, _homedir2.default)() + '/.openbazaar2.0-clientData';
}

var userDataPath = _yargs.argv.userData || defaultUserDataPath;

// If you pass in a specific userData value as a command line option, we'll use that.
// Otherwise, if you're using the bundled app, we'll use a custom data dir (as defined
// in the switch above). Otherwise (running client from source), we won't update the data
// dir and the electron default will be used.
if (isBundledApp || _yargs.argv.userData) {
  try {
    _electron.app.setPath('userData', userDataPath);
  } catch (e) {
    _electron.dialog.showErrorBox('Error setting the user data path', 'There was an error setting the user data path to ' + userDataPath + '\n\n' + e);
    _electron.app.exit();
  }
}

_electron.crashReporter.start({
  productName: 'OpenBazaar 2',
  companyName: 'OpenBazaar',
  submitURL: 'http://104.131.17.128:1127/post',
  autoSubmit: true,
  extra: {
    bundled: isBundledApp
  }
});

/**
 * Prevent window navigation
 *
 * @param  {Object} win Contains a browserwindow object
 */
function preventWindowNavigation(win) {
  win.webContents.on('will-navigate', function (e, url) {
    // NB: Let page reloads through.
    if (url === win.webContents.getURL()) return;

    e.preventDefault();
  });
}

function createWindow() {
  // Check for updates an hour after the last check
  var checkForUpdatesInterval = void 0;

  var checkForUpdates = function checkForUpdates() {
    clearInterval(checkForUpdatesInterval);
    _electron.autoUpdater.checkForUpdates();
    checkForUpdatesInterval = setInterval(function () {
      _electron.autoUpdater.checkForUpdates();
    }, 60 * 60 * 1000);
  };

  var helpSubmenu = [{
    label: 'Website',
    click: function click() {
      _electron.shell.openExternal('https://openbazaar.org');
    }
  },
  // until the documentation page is updated, don't show it
  /*
  {
    label: 'Documentation',
    click() {
      shell.openExternal('https://docs.openbazaar.org');
    },
  },
  */
  {
    label: 'Support',
    click: function click() {
      _electron.shell.openExternal('https://openbazaar.org/support');
    }
  }];

  if (isBundledApp) {
    helpSubmenu = [{
      label: updatesSupported ? 'Check for Updates...' : 'Download Latest',
      click: function click() {
        if (updatesSupported) {
          checkForUpdates();
        } else {
          _electron.shell.openExternal('https://www.openbazaar.org/download/');
        }
      }
    }, {
      type: 'separator'
    }].concat(_toConsumableArray(helpSubmenu));
  }

  var viewSubmenu = [{
    label: 'Reload',
    accelerator: 'CmdOrCtrl+R',
    click: function click(item, focusedWindow) {
      if (focusedWindow) focusedWindow.reload();
    }
  }, {
    label: 'Toggle Developer Tools',
    accelerator: process.platform === 'darwin' ? 'Alt+Command+I' : 'Ctrl+Shift+I',
    click: function click(item, focusedWindow) {
      if (focusedWindow) focusedWindow.webContents.toggleDevTools();
    }
  }, {
    role: 'togglefullscreen'
  }, {
    role: 'zoomin',
    accelerator: 'CommandOrControl+='
  }, {
    role: 'zoomout',
    accelerator: 'CommandOrControl+-'
  }, {
    role: 'resetzoom'
  }];

  var template = [{
    label: 'Edit',
    submenu: [{
      role: 'undo'
    }, {
      role: 'redo'
    }, {
      type: 'separator'
    }, {
      role: 'cut'
    }, {
      role: 'copy'
    }, {
      role: 'paste'
    }, {
      role: 'pasteandmatchstyle'
    }, {
      role: 'delete'
    }, {
      role: 'selectall'
    }]
  }, {
    label: 'View',
    submenu: viewSubmenu
  }, {
    role: 'window',
    submenu: [{
      role: 'minimize'
    }, {
      role: 'close'
    }]
  }, {
    role: 'help',
    submenu: helpSubmenu
  }];

  if (process.platform === 'darwin') {
    var name = _electron.app.getName();
    template.unshift({
      label: name,
      submenu: [{
        role: 'about'
      }, {
        type: 'separator'
      }, {
        role: 'services',
        submenu: []
      }, {
        type: 'separator'
      }, {
        role: 'hide'
      }, {
        role: 'hideothers'
      }, {
        role: 'unhide'
      }, {
        type: 'separator'
      }, {
        role: 'quit',
        accelerator: 'CmdOrCtrl+Q',
        click: function click() {
          closeConfirmed = true;
          _electron.app.quit();
        }
      }]
    });
    // Edit menu.
    template[1].submenu.push({
      type: 'separator'
    }, {
      label: 'Speech',
      submenu: [{
        role: 'startspeaking'
      }, {
        role: 'stopspeaking'
      }]
    });
    // Window menu.
    template[3].submenu = [{
      label: 'Close',
      accelerator: 'CmdOrCtrl+W',
      role: 'close'
    }, {
      label: 'Minimize',
      accelerator: 'CmdOrCtrl+M',
      role: 'minimize'
    }, {
      label: 'Zoom',
      role: 'zoom'
    }, {
      type: 'separator'
    }, {
      label: 'Bring All to Front',
      role: 'front'
    }];
  }

  var menu = _electron.Menu.buildFromTemplate(template);
  _electron.Menu.setApplicationMenu(menu);

  _electron.ipcMain.on('contextmenu-click', function () {
    menu.popup();
  });

  // put logic here to set tray icon based on OS
  var osTrayIcon = 'openbazaar-system-tray.png';
  if (process.platform === 'darwin') osTrayIcon = 'openbazaar-mac-system-tray.png';

  trayMenu = new _electron.Tray(__dirname + '/imgs/' + osTrayIcon);

  var trayTemplate = [];

  if (localServer) {
    trayTemplate = [{
      label: 'Start Local Server',
      type: 'normal',
      click: function click() {
        localServer.start();
      }
    }, {
      label: 'Shutdown Local Server',
      type: 'normal',
      click: function click() {
        localServer.stop();
      }
    }, {
      label: 'View Server Debug Log',
      type: 'normal',
      click: function click() {
        mainWindow.focus();
        mainWindow.restore();
        mainWindow.webContents.send('show-server-log');
      }
    }, {
      type: 'separator'
    }];
  }

  trayTemplate.push({
    label: 'Quit',
    type: 'normal',
    accelerator: 'Command+Q',
    click: function click() {
      _electron.app.quit();
    }
  });

  var contextMenu = _electron.Menu.buildFromTemplate(trayTemplate);

  trayMenu.setContextMenu(contextMenu);

  if (localServer) {
    if (localServer.isRunning) {
      contextMenu.items[0].enabled = false;
    } else {
      contextMenu.items[1].enabled = false;
    }

    (0, _mainProcLocalServerEvents.bindLocalServerEvent)('start', function () {
      contextMenu.items[0].enabled = false;
      contextMenu.items[1].enabled = true;
    });

    (0, _mainProcLocalServerEvents.bindLocalServerEvent)('exit', function () {
      contextMenu.items[0].enabled = true;
      contextMenu.items[1].enabled = false;
    });

    // we'll enable the debug log when our serverConnect module is ready
    contextMenu.items[2].enabled = false;
    _electron.ipcMain.on('server-connect-ready', function () {
      return contextMenu.items[2].enabled = true;
    });
  }

  // Create the browser window.
  mainWindow = new _electron.BrowserWindow({
    width: 1200,
    height: 760,
    minWidth: 1170,
    minHeight: 700,
    center: true,
    title: 'OpenBazaar',
    frame: false,
    icon: __dirname + '/imgs/icon.png'
  });

  // and load the index.html of the app.
  mainWindow.loadURL('file://' + __dirname + '/.tmp/index.html');

  _electron.ipcMain.on('set-proxy', function (e, id) {
    var socks5Setting = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

    if (!id) {
      throw new Error('Please provide an id that will be passed back with the "proxy-set" ' + 'event.');
    }

    mainWindow.webContents.session.setProxy({
      proxyRules: socks5Setting,
      proxyBypassRules: '<local>'
    }, function () {
      return mainWindow.webContents.send('proxy-set', id);
    });
  });

  // Open the DevTools.
  if (process.env.NODE_ENV === 'development') {
    mainWindow.webContents.openDevTools({
      detach: true
    });
  }

  // Emitted when the window is closed.
  mainWindow.on('closed', function () {
    // Dereference the window object, usually you would store windows
    // in an array if your app supports multi windows, this is the time
    // when you should delete the corresponding element.
    mainWindow = null;
    _electron.app.quit();
  });

  mainWindow.on('close', function (e) {
    mainWindow.send('close-attempt');

    if (mainWindow && !closeConfirmed) {
      e.preventDefault();
    }
  });

  /**
   * If there is an update available then we will send an IPC message to the
   * render process to notify the user. If the user wants to update
   * the software then they will send an IPC message back to the main process and we will
   * begin to download the file and update the software.
   */
  if (isBundledApp) {
    _electron.autoUpdater.on('checking-for-update', function () {
      mainWindow.send('updateChecking');
      mainWindow.send('consoleMsg', 'Checking for update at ' + _electron.autoUpdater.getFeedURL());
    });

    _electron.autoUpdater.on('error', function (err, msg) {
      mainWindow.send('consoleMsg', msg);
      mainWindow.send('updateError', msg);
    });

    _electron.autoUpdater.on('update-not-available', function () {
      mainWindow.send('updateNotAvailable');
    });

    _electron.autoUpdater.on('update-available', function () {
      mainWindow.send('updateAvailable');
    });

    _electron.autoUpdater.on('update-downloaded', function (e, releaseNotes, releaseName, releaseDate, updateUrl) {
      var opts = {};
      opts.Name = releaseName;
      opts.URL = updateUrl;
      opts.Date = releaseDate;
      opts.Notes = releaseNotes;
      mainWindow.send('updateReadyForInstall', opts);
    });

    // Listen for installUpdate command to install the update
    _electron.ipcMain.on('installUpdate', function () {
      _electron.autoUpdater.quitAndInstall();
    });

    // Listen for checkForUpdate command to manually check for new versions
    _electron.ipcMain.on('checkForUpdate', function () {
      checkForUpdates();
    });

    _electron.autoUpdater.setFeedURL(feedURL);
  }

  mainWindow.webContents.on('dom-ready', function () {
    // Check for an update once the DOM is ready so the update dialog box can be shown
    if (isBundledApp) checkForUpdates();
  });

  // Set up protocol
  _electron.app.setAsDefaultProtocolClient('ob');

  // Check for URL hijacking in the browser
  preventWindowNavigation(mainWindow);
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
_electron.app.on('ready', createWindow);

// Quit when all windows are closed.
_electron.app.on('window-all-closed', function () {
  // On macOS it is common for applications and their Menu bar
  // to stay active until the user quits explicitly with Cmd + Q
  if (process.platform !== 'darwin') {
    _electron.app.quit();
  }
});

_electron.app.on('activate', function () {
  if (mainWindow) mainWindow.show();
});

var handleObLink = function handleObLink(route) {
  if (!route || typeof route !== 'string') {
    throw new Error('Please provide a route as a string.');
  }

  global.externalRoute = route;

  if (mainWindow) {
    // if our app router is fully loaded it will process the event sent below, otherwise
    // the global.externalRoute will be used
    mainWindow.webContents.send('external-route', route);
  }
};

_electron.app.on('open-url', function (e, uri) {
  e.preventDefault();
  var url = uri.split('://')[1];

  if (url) {
    handleObLink(url);
  }
});

_electron.ipcMain.on('close-confirmed', function () {
  closeConfirmed = true;

  if (mainWindow) mainWindow.close();
});

// If appropriate, add in Basic Auth headers to each request. If connecting to
// the built-in server, we'll add in the auth token.
_electron.ipcMain.on('active-server-set', function (e, server) {
  var filter = {
    urls: [server.httpUrl + '*', server.socketUrl + '*']
  };

  _electron.session.defaultSession.webRequest.onBeforeSendHeaders(filter, function (details, callback) {
    if (server.authenticate) {
      var un = server.username;
      var pw = server.password;

      details.requestHeaders.Authorization = 'Basic ' + new Buffer(un + ':' + pw).toString('base64');
    }

    if (global.authCookie && server.builtIn) {
      details.requestHeaders.Cookie = 'OpenBazaar_Auth_Cookie=' + global.authCookie;
    }

    callback({ cancel: false, requestHeaders: details.requestHeaders });
  });
});

// some cleanup when our app is exiting
process.on('exit', function () {
  closeConfirmed = true;
  _electron.app.quit();
  if (localServer) localServer.stop();
});

// Aggreate and make available the localServer and serverConnect
// module logs into one cohesive server log.
var log = function log(msg) {
  if (typeof msg !== 'string') {
    throw new Error('Please provide a message as a string.');
  }

  if (!msg) return;

  // Prevent the logs / msg from getting so large it eats up all the ram
  // and crashes the client.
  var message = msg.slice(msg.length - 500000);
  global.serverLog += message;
  global.serverLog = global.serverLog.slice(global.serverLog.length - 2000000);

  if (mainWindow) {
    mainWindow.webContents.send('server-log', message);
  }
};

if (localServer) (0, _mainProcLocalServerEvents.bindLocalServerEvent)('log', function (localServ, msg) {
  return log(msg);
});
_electron.ipcMain.on('server-connect-log', function (e, msg) {
  return log(msg);
});

_electron.ipcMain.on('set-badge-count', function (event, count) {
  // setBadgeCount is only available on certain environements:
  // https://github.com/electron/electron/blob/master/docs/api/app.md#appsetbadgecountcount-linux-macos
  try {
    _electron.app.setBadgeCount(count);
  } catch (err) {
    // pass
    console.log(err);
  }
});
