'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

exports.getNotifDisplayData = getNotifDisplayData;

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _backbone = require('backbone');

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _class = function (_Collection) {
  _inherits(_class, _Collection);

  function _class() {
    _classCallCheck(this, _class);

    return _possibleConstructorReturn(this, (_class.__proto__ || Object.getPrototypeOf(_class)).apply(this, arguments));
  }

  _createClass(_class, [{
    key: 'url',
    value: function url() {
      return _app2.default.getServerUrl('ob/notifications');
    }
  }, {
    key: 'parse',
    value: function parse(response) {
      return response.notifications.map(function (notif) {
        var innerNotif = notif.notification;

        return _extends({
          id: innerNotif.notificationId,
          notification: _underscore2.default.omit(innerNotif, 'notificationId')
        }, notif);
      });
    }
  }, {
    key: 'comparator',
    value: function comparator(message) {
      return message.get('timestamp');
    }
  }]);

  return _class;
}(_backbone.Collection);

/**
 * Based on a notification's data, this function will determine what text
 * the notification should be displayed with and what route it should link to.
 * Based on option.native, it will tailor the text for it to be used on a native
 * JS notification or our internal app one (the former can't contain html).
 *
 * @param {object} attrs - The notification data, If you have a Notification model,
 *   then this is the embedded notification object (i.e. this.model.toJSON().notification).
 * @param {object} [options={}]
 * @return {object} An object containting text and route properties.
 */


exports.default = _class;
function getNotifDisplayData(attrs) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if ((typeof attrs === 'undefined' ? 'undefined' : _typeof(attrs)) !== 'object') {
    throw new Error('Please provide an object with notification data.');
  }

  var opts = _extends({
    native: false
  }, options);

  var text = '';
  var route = '';

  var getName = function getName(handle, guid) {
    return handle && '@' + handle || guid.slice(0, 8) + '\u2026';
  };

  if (attrs.type === 'order') {
    var buyerName = opts.native ? getName(attrs.buyerHandle, attrs.buyerId) : '<a class="clrTEm" href="#' + attrs.buyerId + '">' + getName(attrs.buyerHandle, attrs.buyerId) + '</a>';
    var listingTitle = opts.native ? attrs.title : '<a class="clrTEm" href="#' + _app2.default.profile.id + '/store/' + attrs.slug + '">' + attrs.title + '</a>';

    route = '#transactions/sales?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.order', {
      buyerName: buyerName,
      listingTitle: listingTitle
    });
  } else if (attrs.type === 'payment') {
    route = '#transactions/purchases?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.payment');
  } else if (attrs.type === 'orderConfirmation') {
    var vendorName = opts.native ? getName(attrs.vendorHandle, attrs.vendorId) : '<a class="clrTEm" href="#' + attrs.vendorId + '">' + (getName(attrs.vendorHandle, attrs.vendorId) + '</a>');
    route = '#transactions/purchases?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.orderConfirmation', {
      vendorName: vendorName
    });
  } else if (attrs.type === 'declined') {
    var _vendorName = opts.native ? getName(attrs.vendorHandle, attrs.vendorId) : '<a class="clrTEm" href="#' + attrs.vendorId + '">' + (getName(attrs.vendorHandle, attrs.vendorId) + '</a>');
    route = '#transactions/purchases?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.declined', {
      vendorName: _vendorName
    });
  } else if (attrs.type === 'canceled') {
    var _buyerName = opts.native ? getName(attrs.buyerHandle, attrs.buyerId) : '<a class="clrTEm" href="#' + attrs.buyerId + '">' + (getName(attrs.buyerHandle, attrs.buyerId) + '</a>');
    route = '#transactions/sales?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.canceled', {
      buyerName: _buyerName
    });
  } else if (attrs.type === 'refund') {
    var _vendorName2 = opts.native ? getName(attrs.vendorHandle, attrs.vendorId) : '<a class="clrTEm" href="#' + attrs.vendorId + '">' + (getName(attrs.vendorHandle, attrs.vendorId) + '</a>');
    route = '#transactions/purchases?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.refunded', {
      vendorName: _vendorName2
    });
  } else if (attrs.type === 'fulfillment') {
    var _vendorName3 = opts.native ? getName(attrs.vendorHandle, attrs.vendorId) : '<a class="clrTEm" href="#' + attrs.vendorId + '">' + (getName(attrs.vendorHandle, attrs.vendorId) + '</a>');
    route = '#transactions/purchases?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.fulfillment', {
      vendorName: _vendorName3
    });
  } else if (attrs.type === 'orderComplete') {
    var _buyerName2 = opts.native ? getName(attrs.buyerHandle, attrs.buyerId) : '<a class="clrTEm" href="#' + attrs.buyerId + '">' + getName(attrs.buyerHandle, attrs.buyerId) + '</a>';
    route = '#transactions/sales?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.orderComplete', {
      buyerName: _buyerName2
    });
  } else if (attrs.type === 'processingError') {
    var _vendorName4 = opts.native ? getName(attrs.vendorHandle, attrs.vendorId) : '<a class="clrTEm" href="#' + attrs.vendorId + '">' + (getName(attrs.vendorHandle, attrs.vendorId) + '</a>');
    route = '#transactions/purchases?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.processingError', {
      vendorName: _vendorName4
    });
  } else if (attrs.type === 'disputeOpen') {
    if (attrs.disputeeId === _app2.default.profile.id) {
      // notif received by disputee
      var disputerName = opts.native ? getName(attrs.disputerHandle, attrs.disputerId) : '<a class="clrTEm" href="#' + attrs.disputerId + '">' + (getName(attrs.disputerHandle, attrs.disputerId) + '</a>');
      route = '#transactions/' + (attrs.buyer === attrs.disputerId ? 'purchases' : 'sales') + ('?orderId=' + attrs.orderId);
      text = _app2.default.polyglot.t('notifications.text.disputeOpen', {
        disputerName: disputerName
      });
    } else {
      // you are the mod receiving this notification
      var _disputerName = opts.native ? getName(attrs.disputerHandle, attrs.disputerId) : '<a class="clrTEm" href="#' + attrs.disputerId + '">' + (getName(attrs.disputerHandle, attrs.disputerId) + '</a>');
      var disputeeName = opts.native ? getName(attrs.disputeeHandle, attrs.disputeeId) : '<a class="clrTEm" href="#' + attrs.disputeeId + '">' + (getName(attrs.disputeeHandle, attrs.disputeeId) + '</a>');

      route = '#transactions/cases?caseId=' + attrs.orderId;
      text = _app2.default.polyglot.t('notifications.text.disputeOpenMod', {
        disputerName: _disputerName,
        disputeeName: disputeeName
      });
    }
  } else if (attrs.type === 'disputeUpdate') {
    var _disputerName2 = opts.native ? getName(attrs.disputerHandle, attrs.disputerId) : '<a class="clrTEm" href="#' + attrs.disputerId + '">' + (getName(attrs.disputerHandle, attrs.disputerId) + '</a>');
    var _disputeeName = opts.native ? getName(attrs.disputeeHandle, attrs.disputeeId) : '<a class="clrTEm" href="#' + attrs.disputeeId + '">' + (getName(attrs.disputeeHandle, attrs.disputeeId) + '</a>');
    route = '#transactions/cases?orderId=' + attrs.orderId;
    text = _app2.default.polyglot.t('notifications.text.disputeUpdate', {
      disputerName: _disputerName2,
      disputeeName: _disputeeName
    });
  } else if (attrs.type === 'disputeClose') {
    var otherPartyName = opts.native ? getName(attrs.otherPartyHandle, attrs.otherPartyId) : '<a class="clrTEm" href="#' + attrs.otherPartyId + '">' + (getName(attrs.otherPartyHandle, attrs.otherPartyId) + '</a>');
    route = '#transactions/' + (attrs.buyer === attrs.otherPartyId ? 'purchases' : 'sales') + ('?orderId=' + attrs.orderId);
    text = _app2.default.polyglot.t('notifications.text.disputeClose', {
      otherPartyName: otherPartyName
    });
  } else if (attrs.type === 'disputeAccepted') {
    var _otherPartyName = opts.native ? getName(attrs.otherPartyHandle, attrs.otherPartyId) : '<a class="clrTEm" href="#' + attrs.buyerId + '">' + (getName(attrs.otherPartyHandle, attrs.otherPartyId) + '</a>');
    route = '#transactions/' + (attrs.buyer === attrs.otherPartyId ? 'purchases' : 'sales') + ('?orderId=' + attrs.orderId);
    text = _app2.default.polyglot.t('notifications.text.disputeAccepted', {
      otherPartyName: _otherPartyName
    });
  } else if (attrs.type === 'follow' || attrs.type === 'moderatorAdd' || attrs.type === 'moderatorRemove') {
    var name = opts.native ? getName(attrs.handle, attrs.peerId) : '<a class="clrTEm" href="#' + attrs.peerId + '">' + getName(attrs.handle, attrs.peerId) + '</a>';
    route = '#' + attrs.peerId;
    text = _app2.default.polyglot.t('notifications.text.' + attrs.type, {
      name: name
    });
  }

  return {
    text: text,
    route: route
  };
}