'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTranslatedCurrencies = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.getCurrencyByCode = getCurrencyByCode;
exports.getCurrenciesSortedByCode = getCurrenciesSortedByCode;
exports.getServerCurrency = getServerCurrency;
exports.renderCryptoIcon = renderCryptoIcon;
exports.getBlockChainTxUrl = getBlockChainTxUrl;
exports.getBlockChainAddressUrl = getBlockChainAddressUrl;

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _bitcoreLib = require('bitcore-lib');

var _bitcoreLib2 = _interopRequireDefault(_bitcoreLib);

var _bech = require('bech32');

var _bech2 = _interopRequireDefault(_bech);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// If a currency does not support fee bumping or you want to disable it, do not provide a
// feeBumpTransactionSize setting.

var currencies = [{
  code: 'BTC',
  testnetCode: 'TBTC',
  symbol: '₿',
  baseUnit: 100000000,
  minDisplayDecimals: 0,
  maxDisplayDecimals: 8,
  averageModeratedTransactionSize: 184,
  // Not allowing fee bump on BTC right now given the fees.
  // feeBumpTransactionSize: 154,
  qrCodeText: function qrCodeText(address) {
    return 'bitcoin:' + address;
  },
  icon: 'imgs/cryptoIcons/btcIcon128.png',
  url: 'https://bitcoin.org/',
  needCoinLink: 'https://openbazaar.org/bitcoin',
  getBlockChainAddressUrl: function getBlockChainAddressUrl(address, isTestnet) {
    return isTestnet ? 'https://www.blocktrail.com/tBTC/address/' + address : 'https://blockchair.com/bitcoin/address/' + address;
  },
  getBlockChainTxUrl: function getBlockChainTxUrl(txid, isTestnet) {
    return isTestnet ? 'https://www.blocktrail.com/tBTC/tx/' + txid : 'https://blockchair.com/bitcoin/transaction/' + txid;
  },
  canShapeShiftIntoWallet: true,
  canShapeShiftIntoPurchase: false,
  isValidAddress: function isValidAddress(address) {
    if (typeof address !== 'string') {
      throw new Error('Please provide a string.');
    }

    try {
      _bitcoreLib2.default.encoding.Base58Check.decode(address);
      return true;
    } catch (exc) {
      try {
        _bech2.default.decode(address);
        return true;
      } catch (exc2) {
        return false;
      }
    }
  }
}, {
  code: 'BCH',
  testnetCode: 'TBCH',
  baseUnit: 100000000,
  minDisplayDecimals: 0,
  maxDisplayDecimals: 8,
  averageModeratedTransactionSize: 184,
  feeBumpTransactionSize: 154,
  qrCodeText: function qrCodeText(address) {
    return address;
  },
  icon: 'imgs/cryptoIcons/bchIcon128.png',
  url: 'https://bitcoincash.org/',
  getBlockChainAddressUrl: function getBlockChainAddressUrl(address, isTestnet) {
    return isTestnet ? 'https://www.blocktrail.com/tBCC/address/' + address : 'https://blockdozer.com/address/' + address;
  },
  getBlockChainTxUrl: function getBlockChainTxUrl(txid, isTestnet) {
    return isTestnet ? 'https://www.blocktrail.com/tBCC/tx/' + txid : 'https://blockdozer.com/tx/' + txid;
  },
  canShapeShiftIntoWallet: true,
  canShapeShiftIntoPurchase: false
}, {
  code: 'ZEC',
  testnetCode: 'TZEC',
  baseUnit: 100000000,
  minDisplayDecimals: 0,
  maxDisplayDecimals: 8,
  averageModeratedTransactionSize: 184,
  feeBumpTransactionSize: 154,
  qrCodeText: function qrCodeText(address) {
    return 'zcash:' + address;
  },
  icon: 'imgs/cryptoIcons/zecIcon128.png',
  url: 'https://z.cash',
  getBlockChainAddressUrl: function getBlockChainAddressUrl(address, isTestnet) {
    return isTestnet ? 'https://explorer.testnet.z.cash/address/' + address : 'https://explorer.zcha.in/accounts/' + address;
  },
  getBlockChainTxUrl: function getBlockChainTxUrl(txid, isTestnet) {
    return isTestnet ? 'https://explorer.testnet.z.cash/tx/' + txid : 'https://explorer.zcha.in/transactions/' + txid;
  },
  canShapeShiftIntoWallet: true,
  canShapeShiftIntoPurchase: false
}];

exports.default = currencies;


var defaultLangParam = _app2.default && _app2.default.localSettings && _app2.default.localSettings.standardizedTranslatedLang() || 'en-US';
function getTranslatedCurrencies() {
  var lang = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultLangParam;
  var sort = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

  if (!lang) {
    throw new Error('Please provide the language the translated currencies' + ' should be returned in.');
  }

  var translated = currencies.map(function (currency) {
    return _extends({}, currency, {
      name: _app2.default.polyglot.t('cryptoCurrencies.' + currency.code)
    });
  });

  if (sort) {
    translated = translated.sort(function (a, b) {
      return a.name.localeCompare(b.name, lang);
    });
  }

  return translated;
}

var memoizedGetTranslatedCurrencies = _underscore2.default.memoize(getTranslatedCurrencies, function (lang, sort) {
  return lang + '-' + !!sort;
});

exports.getTranslatedCurrencies = memoizedGetTranslatedCurrencies;


var _indexedCurrencies = void 0;

function getIndexedCurrencies() {
  if (_indexedCurrencies) return _indexedCurrencies;

  _indexedCurrencies = memoizedGetTranslatedCurrencies(undefined, false).reduce(function (indexedObj, currency) {
    indexedObj[currency.code] = indexedObj[currency.testnetCode] = _extends({}, currency);
    return indexedObj;
  }, {});

  return _indexedCurrencies;
}

function getCurrencyByCode(code) {
  if (!code) {
    throw new Error('Please provide a currency code.');
  }

  return getIndexedCurrencies()[code];
}

var currenciesSortedByCode = void 0;

function getCurrenciesSortedByCode() {
  if (currenciesSortedByCode) {
    return currenciesSortedByCode;
  }

  currenciesSortedByCode = currencies.sort(function (a, b) {
    if (a.code < b.code) return -1;
    if (a.code > b.code) return 1;
    return 0;
  });

  return currenciesSortedByCode;
}

/**
 * Returns the currency data object based on the currency the connected server is in.
 */
function getServerCurrency() {
  if (!_app2.default || !_app2.default.serverConfig || !_app2.default.serverConfig.cryptoCurrency) {
    throw new Error('The cryptoCurrency field must be set on app.serverConfig.');
  }

  var curData = getCurrencyByCode(_app2.default.serverConfig.cryptoCurrency);

  curData = _extends({}, curData, {
    isTestnet: _app2.default.serverConfig.cryptoCurrency === curData.testnetCode
  });

  return curData;
}

/**
 * Will render the icon for the crypto currency provided in options.code. If not provided, it will
 * attempt to use the server currency. If the currency ends up not having an icon, a blank string
 * will be returned.
 */
function renderCryptoIcon() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var code = options.code;

  if (!code) {
    var serverCur = getServerCurrency();
    code = serverCur && serverCur.code || '';
  }

  var opts = _extends({
    code: code,
    className: '',
    attrs: {}
  }, options);

  var curData = getCurrencyByCode(opts.code);

  if (curData && curData.icon) {
    var attrs = Object.keys(opts.attrs).reduce(function (attrString, key) {
      return attrString + ' ' + key + '="' + opts.attrs[key] + '"';
    }, '');

    var style = 'style="background-image: url(../' + curData.icon + ')"';
    return '<i class="cryptoIcon ' + opts.className + '" ' + attrs + ' ' + style + '></i>';
  }

  return '';
}

function getBlockChainTxUrl(txid, isTestnet) {
  var serverCur = getServerCurrency();

  if (serverCur) {
    return serverCur.getBlockChainTxUrl(txid, isTestnet);
  }

  return '';
}

function getBlockChainAddressUrl(address, isTestnet) {
  var serverCur = getServerCurrency();

  if (serverCur) {
    return serverCur.getBlockChainAddressUrl(address, isTestnet);
  }

  return '';
}