'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultQuantityBaseUnit = undefined;
exports.getCurrencies = getCurrencies;
exports.getCurrenciesSortedByCode = getCurrenciesSortedByCode;
exports.getCurrenciesSortedByName = getCurrenciesSortedByName;

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _currencies = require('../data/currencies');

var _currencies2 = _interopRequireDefault(_currencies);

var _currency = require('../utils/currency');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Since the exchange rate api is dependant on 3rd parties, we can't absolutely rely on
// consistent results, so we'll start with a hard-coded list of crypto-listing currencies.
// The base list could be updated from release to release. If there are additional crypto
// currencies being returned by the exchange rate api, they will be merged into a combined
// list the UI will use.
var baseCurrencies = ['BTC', 'ADA', 'ARK', 'BCH', 'BCN', 'BTCD', 'BTG', 'BTS', 'DASH', 'DCR', 'DGB', 'DOGE', 'ETC', 'ETH', 'FCT', 'HSR', 'IOTA', 'KMD', 'LSK', 'LTC', 'MONA', 'NANO', 'NEBL', 'NEO', 'NXS', 'NXT', 'PIVX', 'QTUM', 'RDD', 'SC', 'STEEM', 'STRAT', 'SYS', 'VEN', 'WAVES', 'XDN', 'XEM', 'XLM', 'XMR', 'XRP', 'XVC', 'XVG', 'ZCL', 'ZEC'];

// Certain currencies are not in our fiat list, but they're also not crypto currencies.
// They mainly conisist of obscure fiat currencies or precious metals.
var excludes = ['BYN', 'CLF', 'CNH', 'CUC', 'GGP', 'JEP', 'IMP', 'XAG', 'XAU', 'XDR', 'XPD', 'XPT'];

var fiatCurrencyCodes = void 0;
var currencies = void 0;
var exchangeRateCurs = [];
var currenciesNeedRefresh = true;
var exchangeRateChangeBound = false;

function getCurrencies() {
  if (!exchangeRateChangeBound) {
    (0, _currency.getEvents)().on('exchange-rate-change', function () {
      if (!currenciesNeedRefresh && !_underscore2.default.isEqual(Object.keys((0, _currency.getExchangeRates)()).sort(), exchangeRateCurs)) {
        currenciesNeedRefresh = true;
      }
    });
    exchangeRateChangeBound = true;
  }

  if (currencies && !currenciesNeedRefresh) return currencies;

  if (!fiatCurrencyCodes) {
    fiatCurrencyCodes = _currencies2.default.map(function (cur) {
      return cur.code;
    });
  }

  var curs = new Set();
  baseCurrencies.forEach(function (cur) {
    return curs.add(cur);
  });
  var _exchangeRateCurs = Object.keys((0, _currency.getExchangeRates)());
  exchangeRateCurs = _exchangeRateCurs.sort();
  _exchangeRateCurs.forEach(function (cur) {
    // If it's not a fiat currency code (base on our hard-code list),
    // or on our exclude list, we'll assume it's a crypto currency.
    if (!fiatCurrencyCodes.includes(cur) && !excludes.includes(cur)) {
      curs.add(cur);
    }
  });

  // We'll merge in any previous currencies we had, so the UI lists don't potentially have
  // currencies that are there at one point and then gone later. If the exchange rate for
  // a particular currency is no longer available, the UI will reflect that.
  if (currencies) {
    currencies.forEach(function (cur) {
      return curs.add(cur);
    });
  }

  currenciesNeedRefresh = false;
  currencies = Array.from(curs);
  return currencies;
}

var currenciesSortedByCode = void 0;

function getCurrenciesSortedByCode() {
  if (currenciesSortedByCode && !currenciesNeedRefresh) {
    return currenciesSortedByCode;
  }

  currenciesSortedByCode = getCurrencies().sort();

  return currenciesSortedByCode;
}

var currenciesSortedByName = void 0;
var defaultLang = _app2.default && _app2.default.localSettings && _app2.default.localSettings.standardizedTranslatedLang() || 'en-US';

function getCurrenciesSortedByName() {
  var lang = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultLang;

  if (currenciesSortedByName && !currenciesNeedRefresh) {
    return currenciesSortedByName;
  }

  currenciesSortedByName = getCurrencies().sort(function (a, b) {
    var aTranslationKey = 'cryptoCurrencies.' + a;
    var bTranslationKey = 'cryptoCurrencies.' + b;
    var aName = _app2.default.polyglot.t(aTranslationKey) === aTranslationKey ? a : _app2.default.polyglot.t(aTranslationKey);
    var bName = _app2.default.polyglot.t(bTranslationKey) === bTranslationKey ? b : _app2.default.polyglot.t(bTranslationKey);
    return aName.localeCompare(bName, lang);
  });

  return currenciesSortedByName;
}

var defaultQuantityBaseUnit = exports.defaultQuantityBaseUnit = 100000000;