'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _object = require('../utils/object');

var _backbone = require('backbone');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*

  The Base Model manages nested attributes by creating Model or Collection instances
  for them as defined in the nested attribute (which the developer is to declare).

  (Please note: this is intented for models that interface with APIs that return nested
   atttributes, i.e. for a model that interfaces with a single API)

  First off, you want to declare your nested members by implementing a 'nested' function
  that returns an object of key value pairs. The key represents the key of the nested
  attribute as it is returned by the API. The value represents the Model or Collection that is
  to be created to manage the corresponding attributes.

  For example:

  import { Model, Collection } from 'backbone';
  import CustomModel from './models';
  import CustomCollection from './collections';

  class ParentModel extends BaseModel {
    get nested() {
      return {
        SMTPSettings: Model,
        serverConfig: CustomModel,
        addresses: Collection,
        listings: CustomCollection,
      }
    }
  }

  The main reason you would want to provide a custom Model / Collection is if you want to
  declare defaults for the nested attributes.

  === setting nested attributes ===

  You have multiple options:

  // can be done during the parent creation
  const parentModel = new ParentModel({
    SMTPSettings: {
      notifications: false,
    }
  });

  // can be set via the parent
  parentModel.set({
    SMTPSettings: {
      notifications: false,
    }
  });

  // can be set directly on the nested model / collection (see note)
  parentModel.get('SMTPSettings').set('notifications', false);

  Please Note: For a nested collection, unless the models have IDs, it's
  recommended that you directly update the models on the nested collection,
  at least if you want the relevant events to fire properly.

  === saving nested attributes ===

  This is something you want to do via the parent:

  parentModel.save();

  parentModel.save({
    SMTPSettings: {
      notifications: false,
    }
  });

  === events ===

  Events related to the nested attributes need to be directly bound to the nested
  model / collection (e,g. if a nested model changes, the parent's change event
  will -not- fire):

  this.listenTo(parentModel.get('SMTPSettings'), 'change', () => {});
  this.listenTo(parentModel.get('SMTPSettings'), 'change:notifications', () => {});
  this.listenTo(parentModel.get('addresses'), 'update', () => {});
  this.listenTo(parentModel.get('addresses'), 'add remove', () => {});
  this.listenTo(parentModel.get('addresses'), 'change:street', () => {});
*/

var _class = function (_Model) {
  _inherits(_class, _Model);

  function _class() {
    var _ref;

    _classCallCheck(this, _class);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var _this = _possibleConstructorReturn(this, (_ref = _class.__proto__ || Object.getPrototypeOf(_class)).call.apply(_ref, [this].concat(args)));

    _this.lastSyncedAttrs = {};

    _this.on('sync', function () {
      _this.lastSyncedAttrs = JSON.parse(JSON.stringify(_this.toJSON()));
    });
    return _this;
  }

  _createClass(_class, [{
    key: 'set',
    value: function set(key, val) {
      var _this2 = this;

      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      // Handle both `"key", value` and `{key: value}` -style arguments.
      var attrs = void 0;
      var opts = options;

      if ((typeof key === 'undefined' ? 'undefined' : _typeof(key)) === 'object') {
        attrs = key;
        opts = val || {};
      } else {
        (attrs = {})[key] = val;
      }

      // take a snapshot of the attrs provided to this method
      var setAttrs = JSON.parse(JSON.stringify(attrs));

      var previousAttrs = this.toJSON();

      // todo: will it break things if we unset a nested attribute?
      if (!opts.unset) {
        // let's work off of a clone since we modify attrs
        attrs = JSON.parse(JSON.stringify(attrs));

        if (this.nested) {
          var nested = _underscore2.default.result(this, 'nested', []);

          Object.keys(nested).forEach(function (nestedKey) {
            var NestedClass = nested[nestedKey];
            var nestedData = attrs[nestedKey];
            var nestedInstance = _this2.attributes[nestedKey];

            if (nestedData) {
              if (nestedData instanceof NestedClass) {
                attrs[nestedKey] = nestedData;
              } else if (nestedInstance) {
                if (nestedInstance instanceof _backbone.Model) {
                  nestedInstance.set(nestedInstance.parse(nestedData));
                } else {
                  nestedInstance.set(nestedData, { parse: true });
                }

                delete attrs[nestedKey];
              } else {
                attrs[nestedKey] = new NestedClass(nestedData, { parse: true });
              }
            }
          });
        }
      }

      var superSet = _get(_class.prototype.__proto__ || Object.getPrototypeOf(_class.prototype), 'set', this).call(this, attrs, opts);

      // Since the standard change event doesn't properly take into
      // account nested models, we'll fire our own event if any part of the
      // model (including nested parts) change.
      if (!_underscore2.default.isEqual(this.toJSON(), previousAttrs)) {
        this.trigger('someChange', this, { setAttrs: setAttrs });
      }

      return superSet;
    }
  }, {
    key: 'mergeInNestedModelErrors',
    value: function mergeInNestedModelErrors() {
      var _this3 = this;

      var errObj = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      var nested = _underscore2.default.result(this, 'nested', []);
      var prefixedErrs = {};

      Object.keys(nested || {}).forEach(function (key) {
        if (_this3.get(key) instanceof _backbone.Model) {
          var nestedMd = _this3.get(key);
          var nestedErrs = nestedMd.isValid() ? {} : nestedMd.validationError;

          Object.keys(nestedErrs).forEach(function (nestedErrKey) {
            var prefixedKey = key + '.' + nestedErrKey;
            prefixedErrs[prefixedKey] = errObj[prefixedKey] || [];
            prefixedErrs[prefixedKey].push(nestedErrs[nestedErrKey]);
          });
        }
      });

      return _extends({}, errObj, prefixedErrs);
    }
  }, {
    key: 'mergeInNestedCollectionErrors',
    value: function mergeInNestedCollectionErrors() {
      var _this4 = this;

      var errObj = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      var nested = _underscore2.default.result(this, 'nested', []);
      var mergedErrs = errObj;

      Object.keys(nested || {}).forEach(function (key) {
        if (_this4.get(key) instanceof _backbone.Collection) {
          var nestedCl = _this4.get(key);

          nestedCl.forEach(function (nestedMd) {
            var prefixedErrs = {};
            var nestedMdErrs = nestedMd.isValid() ? {} : nestedMd.validationError;

            Object.keys(nestedMdErrs).forEach(function (nestedMdErrKey) {
              // since indexes can change, we'll index using the model's client id (cid)
              var prefixedKey = key + '[' + nestedMd.cid + '].' + nestedMdErrKey;
              prefixedErrs[prefixedKey] = errObj[prefixedKey] || [];
              prefixedErrs[prefixedKey].push(nestedMdErrs[nestedMdErrKey]);
            });

            mergedErrs = _extends({}, mergedErrs, prefixedErrs);
          });
        }
      });

      return mergedErrs;
    }
  }, {
    key: 'mergeInNestedErrors',
    value: function mergeInNestedErrors() {
      var errObj = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return _extends({}, errObj, this.mergeInNestedModelErrors(errObj), this.mergeInNestedCollectionErrors(errObj));
    }
  }, {
    key: 'toJSON',
    value: function toJSON() {
      var attrs = _get(_class.prototype.__proto__ || Object.getPrototypeOf(_class.prototype), 'toJSON', this).call(this);

      if (this.nested) {
        var nested = _underscore2.default.result(this, 'nested', []);
        Object.keys(nested).forEach(function (nestedKey) {
          if (attrs[nestedKey]) {
            attrs[nestedKey] = attrs[nestedKey].toJSON();
          }
        });
      }

      return attrs;
    }

    /**
     * Will reset the models attributes to the last synced ones or
     * the default ones.
     */

  }, {
    key: 'reset',
    value: function reset() {
      if (Object.keys(this.lastSyncedAttrs).length) {
        this.set(JSON.parse(JSON.stringify(this.lastSyncedAttrs)));
      } else {
        this.clear();
        this.set(_underscore2.default.result(this, 'defaults', {}));
      }

      this.validationError = null;
    }
  }, {
    key: 'clone',
    value: function clone() {
      var clone = new this.constructor(this.toJSON());

      clone.lastSyncedAttrs = this.lastSyncedAttrs;

      return clone;
    }
  }, {
    key: 'sync',
    value: function sync(method, model, options) {
      if ((method === 'create' || method === 'update') && options.attrs) {
        options.attrs = (0, _object.removeProp)(options.attrs, '_clientID');
      }

      return _get(_class.prototype.__proto__ || Object.getPrototypeOf(_class.prototype), 'sync', this).call(this, method, model, options);
    }
  }]);

  return _class;
}(_backbone.Model);

exports.default = _class;