'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.standardizedTranslatedLang = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _electron = require('electron');

var _backboneLocalStorage = require('../utils/lib/backboneLocalStorage');

var _backboneLocalStorage2 = _interopRequireDefault(_backboneLocalStorage);

var _backbone = require('backbone');

var _is_js = require('is_js');

var _is_js2 = _interopRequireDefault(_is_js);

var _fees = require('../utils/fees');

var _languages = require('../data/languages');

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Will convert a transifex style language tag to the standard format JS understands as
 * best as it can. For example, `ca_ES` will be returned as  `ca-ES` and `ca@valencia` will
 * be returned as `ca`. It's still probably a good idea to wrap any JS that deals with these
 * codes in a try/catch (e.g. localeCompare) since even a standardized transifex code may not
 * map to something JS understands.
 */
function _standardizedTranslatedLang(lang) {
  if (!lang || typeof lang !== 'string') {
    throw new Error('Please provide a language as a string.');
  }

  return lang.replace('_', '-').slice(0, lang.indexOf('@') > -1 ? lang.indexOf('@') : lang.length);
}

exports.standardizedTranslatedLang = _standardizedTranslatedLang;

var _class = function (_Model) {
  _inherits(_class, _Model);

  function _class() {
    _classCallCheck(this, _class);

    return _possibleConstructorReturn(this, (_class.__proto__ || Object.getPrototypeOf(_class)).apply(this, arguments));
  }

  _createClass(_class, [{
    key: 'localStorage',
    value: function localStorage() {
      return new _backboneLocalStorage2.default('__localSettings');
    }
  }, {
    key: 'sync',
    value: function sync() {
      for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return _backboneLocalStorage2.default.sync.apply(this, args);
    }
  }, {
    key: 'defaults',
    value: function defaults() {
      var langDataObj = void 0;

      try {
        langDataObj = (0, _languages.getTranslationLangByCode)(navigator.language.replace('-', '_'));
      } catch (e) {
        // pass
      }

      var language = langDataObj && langDataObj.code || 'en_US';

      return {
        windowControlStyle: _electron.remote.process.platform === 'darwin' ? 'mac' : 'win',
        showAdvancedVisualEffects: true,
        saveTransactionMetadata: true,
        defaultTransactionFee: 'NORMAL',
        language: language,
        listingsGridViewType: 'grid',
        bitcoinUnit: 'BTC',
        verifiedModsProvider: 'https://search.ob1.io/verified_moderators',
        verifiedModsProviderTor: 'http://my7nrnmkscxr32zo.onion/verified_moderators',
        dontShowTorExternalLinkWarning: false
      };
    }
  }, {
    key: 'standardizedTranslatedLang',
    value: function standardizedTranslatedLang() {
      return _standardizedTranslatedLang(this.get('language'));
    }
  }, {
    key: 'validate',
    value: function validate(attrs) {
      var errObj = {};
      var addError = function addError(fieldName, error) {
        errObj[fieldName] = errObj[fieldName] || [];
        errObj[fieldName].push(error);
      };

      if (!this.controlStyles.includes(attrs.windowControlStyle)) {
        addError('windowControlStyle', 'Please provide one of ' + this.controlStyles + '.');
      }

      if (!this.viewStyles.includes(attrs.listingsGridViewType)) {
        addError('ListingGrideViewType needs to be one of ' + this.viewStyles + '.');
      }

      if (!_fees.feeLevels.includes(attrs.defaultTransactionFee)) {
        addError('defaultTransactionFee', 'The fee level must be one of ' + _fees.feeLevels.join(', '));
      }

      if (!this.bitcoinUnits.includes(attrs.bitcoinUnit)) {
        addError('bitcoinUnit needs to be one of ' + this.bitcoinUnits + '.');
      }

      if (_is_js2.default.not.url(attrs.verifiedModsProvider)) {
        addError('verifiedModsProvider', _app2.default.polyglot.t('localSettingsModelErrors.verifiedModsProvider'));
      }

      if (typeof attrs.dontShowTorExternalLinkWarning !== 'boolean') {
        addError('dontShowTorExternalLinkWarning', 'dontShowTorExternalLinkWarning must be provided as a boolean.');
      }

      if (Object.keys(errObj).length && errObj) return errObj;

      return undefined;
    }
  }, {
    key: 'controlStyles',
    get: function get() {
      return ['mac', 'win'];
    }
  }, {
    key: 'viewStyles',
    get: function get() {
      return ['list', 'grid'];
    }
  }, {
    key: 'bitcoinUnits',
    get: function get() {
      return ['BTC', 'MBTC', 'UBTC', 'SATOSHI'];
    }
  }]);

  return _class;
}(_backbone.Model);

exports.default = _class;