'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _currency = require('../../utils/currency');

var _BaseModel2 = require('../BaseModel');

var _BaseModel3 = _interopRequireDefault(_BaseModel2);

var _Contract = require('./Contract');

var _Contract2 = _interopRequireDefault(_Contract);

var _app = require('../../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _class = function (_BaseModel) {
  _inherits(_class, _BaseModel);

  function _class() {
    _classCallCheck(this, _class);

    return _possibleConstructorReturn(this, (_class.__proto__ || Object.getPrototypeOf(_class)).apply(this, arguments));
  }

  _createClass(_class, [{
    key: 'url',
    value: function url() {
      return _app2.default.getServerUrl('ob/case/' + this.id);
    }
  }, {
    key: 'isContractValid',


    /**
     * - If the contract hasn't arrived, using this logic, it will be considered invalid.
     * - If the vendor had an error processing the order and the buyer's contract is verified
     *   as authentic, the vendor's contract will be considered valid even though it will not
     *   be sent over, since the mod will only be allowed to send the funds to the buyer.
     */
    value: function isContractValid() {
      var buyer = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

      var hasContractArrived = buyer ? !!this.get('buyerContract') : !!this.get('vendorContract');
      var errors = buyer ? this.get('buyerContractValidationErrors') : this.get('vendorContractValidationErrors');

      return hasContractArrived && (!errors || Array.isArray(errors) && !errors.length) || !buyer && this.vendorProcessingError;
    }
  }, {
    key: 'convertCryptoQuantity',
    value: function convertCryptoQuantity() {
      var contract = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      contract.buyerOrder.items.forEach(function (item, index) {
        var listing = contract.vendorListings[index];

        if (listing.metadata.contractType === 'CRYPTOCURRENCY') {
          var coinDivisibility = listing.metadata.coinDivisibility;

          item.quantity = item.quantity / coinDivisibility;
        }
      });

      return contract;
    }
  }, {
    key: 'parse',
    value: function parse() {
      var _this2 = this;

      var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      // If only one contract has arrived, we'll fire an event when the other one comes
      if (!this._otherContractEventBound && !this.vendorProcessingError && (response.buyerOpened && !response.vendorContract || !response.buyerOpened && !response.buyerContract)) {
        var needBuyer = !response.buyerContract;
        this._otherContractEventBound = true;
        this.once('change:' + (needBuyer ? 'buyer' : 'vendor') + 'Contract', function () {
          return _this2.trigger('otherContractArrived', _this2, { isBuyer: needBuyer });
        });
      }

      if (response.buyerContract) {
        // Since we modify the data on parse (particularly in some nested models),
        // we'll store the original contract here.
        response.rawBuyerContract = JSON.parse(JSON.stringify(response.buyerContract)); // deep clone

        // convert price fields
        response.buyerContract.buyerOrder.payment.amount = (0, _currency.integerToDecimal)(response.buyerContract.buyerOrder.payment.amount, _app2.default.serverConfig.cryptoCurrency);

        response.buyerContract = this.convertCryptoQuantity(response.buyerContract);
      }

      if (response.vendorContract) {
        // Since we modify the data on parse (particularly in some nested models),
        // we'll store the original contract here.
        response.rawVendorContract = JSON.parse(JSON.stringify(response.vendorContract)); // deep clone

        // convert price fields
        response.vendorContract.buyerOrder.payment.amount = (0, _currency.integerToDecimal)(response.vendorContract.buyerOrder.payment.amount, _app2.default.serverConfig.cryptoCurrency);
      }

      if (response.resolution) {
        response.resolution.payout.buyerOutput = response.resolution.payout.buyerOutput || {};
        response.resolution.payout.vendorOutput = response.resolution.payout.vendorOutput || {};
        response.resolution.payout.moderatorOutput = response.resolution.payout.moderatorOutput || {};

        response.resolution.payout.buyerOutput.amount = (0, _currency.integerToDecimal)(response.resolution.payout.buyerOutput.amount || 0, _app2.default.serverConfig.cryptoCurrency);
        response.resolution.payout.vendorOutput.amount = (0, _currency.integerToDecimal)(response.resolution.payout.vendorOutput.amount || 0, _app2.default.serverConfig.cryptoCurrency);
        response.resolution.payout.moderatorOutput.amount = (0, _currency.integerToDecimal)(response.resolution.payout.moderatorOutput.amount || 0, _app2.default.serverConfig.cryptoCurrency);
      }

      return response;
    }
  }, {
    key: 'idAttribute',
    get: function get() {
      return 'caseId';
    }
  }, {
    key: 'nested',
    get: function get() {
      return {
        vendorContract: _Contract2.default,
        buyerContract: _Contract2.default
      };
    }

    /**
     * Returns a boolean indicating whether the vendor had an error when processing
     * the order. Since this relies on data from the buyers contract, if the contract is
     * not verified as authentic, false will be returned even if the data suggests
     * otherwise. We don't want to prevent funds from being awared to the vendor based
     * on potentially forged data from the buyer's contract.
     */

  }, {
    key: 'vendorProcessingError',
    get: function get() {
      var contract = this.get('buyerContract');
      var contractErrors = this.get('buyerContractValidationErrors');
      return contract && Array.isArray(contract.get('errors')) && (!contractErrors || !(Array.isArray(contractErrors) && contractErrors.length));
    }
  }, {
    key: 'isBuyerContractValid',
    get: function get() {
      return this.isContractValid();
    }
  }, {
    key: 'isVendorContractValid',
    get: function get() {
      return this.isContractValid(false);
    }
  }, {
    key: 'bothContractsValid',
    get: function get() {
      return this.isBuyerContractValid && this.isVendorContractValid;
    }
  }]);

  return _class;
}(_BaseModel3.default);

exports.default = _class;