'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getGuid = getGuid;
exports.splitIntoRows = splitIntoRows;
exports.abbrNum = abbrNum;
exports.guid = guid;
exports.isMultihash = isMultihash;
exports.selectEmojis = selectEmojis;
exports.setTimeagoInterval = setTimeagoInterval;
exports.deparam = deparam;

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _multihashes = require('multihashes');

var _multihashes2 = _interopRequireDefault(_multihashes);

var _twemoji = require('twemoji');

var _twemoji2 = _interopRequireDefault(_twemoji);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getGuid(handle, resolver) {
  var deferred = _jquery2.default.Deferred();
  var url = resolver || _app2.default.getServerUrl('ob/resolve');

  if (!handle) {
    throw new Error('Please provide a handle.');
  }

  url = url.charAt(url.length - 1) !== '/' ? url + '/' : url;
  url += handle;

  _jquery2.default.get(url).done(function (peerId) {
    return deferred.resolve(peerId);
  }).fail(function (xhr) {
    return deferred.reject(xhr);
  });

  return deferred.promise();
}

// https://www.quora.com/How-do-I-split-a-JSON-array-on-different-rows-in-angularjs/answer/Steve-Schafer-2?srid=G5Pv
/*
 * Splits an array into rows (an array of arrays)
 */
// for now, putting one-off util functions that I don't know where
// else to put here.

function splitIntoRows(items, itemsPerRow) {
  if (!_underscore2.default.isArray(items)) {
    throw new Error('Please provide an array of items');
  }

  if (!_underscore2.default.isNumber(itemsPerRow)) {
    throw new Error('Please provide a number representing the items per row.');
  }

  var rslt = [];

  items.forEach(function (item, index) {
    var rowIndex = Math.floor(index / itemsPerRow);
    var colIndex = index % itemsPerRow;

    if (!rslt[rowIndex]) {
      rslt[rowIndex] = [];
    }

    rslt[rowIndex][colIndex] = item;
  });

  return rslt;
}

// http://stackoverflow.com/a/2686098/632806
function abbrNum(_number) {
  var _maxDecPlaces = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

  // 2 decimal places => 100, 3 => 1000, etc
  var decPlaces = Math.pow(10, _maxDecPlaces);
  var isNegative = _number < 0;
  var number = Math.abs(_number);
  var processed = false;
  var lang = _app2.default && _app2.default.localSettings && _app2.default.localSettings.standardizedTranslatedLang();

  if (!lang) {
    console.warn('Unable to get the languages from the local settings. Using en-US.');
    lang = 'en-US';
  }

  // Enumerate number abbreviations
  var abbrev = ['thousand', 'million', 'billion', 'trillion'];

  // Go through the array backwards, so we do the largest first
  for (var i = abbrev.length - 1; i >= 0; i--) {
    // Convert array index to "1000", "1000000", etc
    var size = Math.pow(10, (i + 1) * 3);

    // If the number is bigger or equal do the abbreviation
    if (size <= number) {
      // Here, we multiply by decPlaces, round, and then divide by decPlaces.
      // This gives us nice rounding to a particular decimal place.
      number = Math.round(number * decPlaces / size) / decPlaces;

      // Handle special case where we round up to the next abbreviation
      if (number === 1000 && i < abbrev.length - 1) {
        number = 1;
        i++;
      }

      number = new Intl.NumberFormat(lang).format(isNegative ? number * -1 : number);
      number = _app2.default.polyglot.t('abbreviatedNumbers.' + abbrev[i], { number: number });

      // We are done... stop
      processed = true;
      break;
    }
  }

  if (!processed) {
    number = new Intl.NumberFormat(lang).format(isNegative ? number * -1 : number);
  }

  return number;
}

// https://github.com/jeromegn/Backbone.localStorage
// Generate four random hex digits.
function s4() {
  return ((1 + Math.random()) * 0x10000 | 0).toString(16).substring(1);
}

// https://github.com/jeromegn/Backbone.localStorage
// Generate a pseudo-GUID by concatenating random hexadecimal.
// This has nothing to do with an OB guid / peerId. This is is just a
// generic way to generate a unique identifier.
function guid() {
  var prefix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  return '' + prefix + s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
}

function isMultihash(_string) {
  try {
    _multihashes2.default.validate(_multihashes2.default.fromB58String(_string));
    return true;
  } catch (exc) {
    return false;
  }
}

// applies a template to select2 to turn text emojis into images
function selectEmojis(option) {
  return (0, _jquery2.default)('<span class="select2ImgOpt">' + _twemoji2.default.parse(option.text, function (icon) {
    return '../imgs/emojis/72X72/' + icon + '.png';
  }) + '</span>');
}

/*
 * If you need to set an interval to update a relative timestamp, this function
 * will smartly decide how often to ping you based on the age of the timestamp.
 * This is important if you have a list of many (dozens, hundreds, etc...) items
 * which would otherwise result in an excess of potentially CPU intensive intervals.
 * @param {string} timestamp
 * @param {function} cb Your callback function that will be called periodically and in which
 * you will likely re-calculate and update your time ago text (e.g. a few seconds ago =>
 * 1 minute ago)
 * @param {array} _timeouts Ignore this argument. It is used internally.
 * @returns {Object} An object with a cancel function so you could cancel this function from
 * calling your callback when you no longer need it. If you initiate this from a view, you would
 * want to call cancel in View.remove().
 */
function setTimeagoInterval(timestamp, cb) {
  var _timeouts = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

  if (!timestamp) {
    throw new Error('Please provide a timestamp.');
  }

  if (typeof cb !== 'function') {
    throw new Error('Please provide a callback function.');
  }

  var age = Date.now() - new Date(timestamp).getTime();

  var pushTimeout = function pushTimeout(time) {
    var timeout = setTimeout(function () {
      cb();
      setTimeagoInterval(timestamp, cb, _timeouts);
    }, time);

    _timeouts.push(timeout);
  };

  if (age < 1000 * 60 * 60) {
    // less than an hour old
    pushTimeout(1000 * 20); // check in 20 seconds
  } else if (age < 1000 * 60 * 60 * 24) {
    // less than a day old
    pushTimeout(1000 * 60 * 15); // check in 15 minutes
  } else if (age < 1000 * 60 * 60 * 24 * 30) {
    // less than 30 days old
    pushTimeout(1000 * 60 * 60 * 2); // check in 2 hours
  } else {
    // more than 30 days old
    pushTimeout(1000 * 60 * 60 * 24); // check in a day
  }

  return {
    cancel: function cancel() {
      _timeouts.forEach(function (timeout) {
        return clearTimeout(timeout);
      });
    }
  };
}

/*
 * Will turn a url encoded query string into a JS object. The opposite of
 * $.param().
 */
function deparam() {
  var queryStr = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  var parsed = {};
  var params = new URLSearchParams(queryStr);

  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = params.entries()[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var pair = _step.value;

      parsed[pair[0]] = pair[1];
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return parsed;
}