'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.prettyRAM = prettyRAM;
exports.freeRAMPercentage = freeRAMPercentage;
exports.userStats = userStats;
exports.isMetricRestartNeeded = isMetricRestartNeeded;
exports.addMetrics = addMetrics;
exports.changeMetrics = changeMetrics;
exports.showMetricsModal = showMetricsModal;
exports.recordEvent = recordEvent;
exports.startEvent = startEvent;
exports.endEvent = endEvent;

var _MetricsModal = require('../views/modals/MetricsModal');

var _MetricsModal2 = _interopRequireDefault(_MetricsModal);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _package = require('../../package.json');

var _os = require('os');

var _serverConnect = require('./serverConnect');

var _electron = require('electron');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var metricsRestartNeeded = false;

function prettyRAM(bytes) {
  // from https://gist.github.com/lanqy/5193417
  var sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB'];
  if (bytes === 0) return '0 bytes';
  var i = parseInt(Math.floor(Math.log(bytes) / Math.log(1024)), 10);
  if (i === 0) return bytes + ' ' + sizes[i] + ')';
  return (bytes / Math.pow(1024, i)).toFixed(1) + ' ' + sizes[i];
}

function freeRAMPercentage(total, free) {
  var percentage = free / total * 100;
  return percentage.toFixed(1) + '%';
}

function userStats() {
  var p = _app2.default.profile;
  var pErr = 'Profile Not Available';
  var torErr = 'No Current Connection';

  return {
    vendor: p ? p.get('vendor') : pErr,
    listingCount: p ? p.get('stats').get('listingCount') : pErr,
    ratingCount: p ? p.get('stats').get('ratingCount') : pErr,
    moderator: p ? p.get('moderator') : pErr,
    crypto: p ? p.get('currencies') : pErr,
    displayCurrency: _app2.default.settings ? _app2.default.settings.get('localCurrency') : 'Settings Not Available',
    displayLanguage: _app2.default.localSettings.get('language'),
    bundled: _electron.remote.getGlobal('isBundledApp'),
    Tor: (0, _serverConnect.getCurrentConnection)() ? (0, _serverConnect.getCurrentConnection)().server.get('useTor') : torErr,
    Testnet: !!_app2.default.serverConfig.testnet,
    systemLanguage: navigator.language,
    numberOfCPUs: (0, _os.cpus)().length, // how many cores?
    CPU: (0, _os.cpus)()[0].model, // how modern/powerful is this computer?
    RAMtotal: prettyRAM((0, _os.totalmem)()), // does the user have enough RAM?
    RAMfree: freeRAMPercentage((0, _os.totalmem)(), (0, _os.freemem)()) // is user overburdening their system?
  };
}

function isMetricRestartNeeded() {
  return metricsRestartNeeded;
}

function addMetrics() {
  function loadMetrics() {
    // Reverse the countly opt out in local storage. This is required or nothing will be tracked.
    window.localStorage.setItem('cly_ignore', 'false');
    metricsRestartNeeded = !!window.Countly;

    //  If Countly has already been added, it won't run again until the app is restarted.
    if (window.Countly) return;

    window.Countly = {};
    window.Countly.q = [];
    window.Countly.app_key = '979774c41bab3a6e5232a3630e6e151e439c412e';
    window.Countly.app_version = 'client_' + _package.version + '|server_' + _app2.default.settings.prettyServerVer;
    window.Countly.url = 'https://countly.openbazaar.org';
    window.Countly.interval = 30000;
    window.Countly.q.push(['track_sessions']);
    window.Countly.q.push(['track_pageview', location.hash]);
    window.Countly.q.push(['track_clicks']);
    window.Countly.q.push(['track_links']);
    window.Countly.q.push(['track_scrolls']);
    window.Countly.q.push(['track_errors']);
    // add anonymous details
    window.Countly.q.push(['user_details', {
      custom: _extends({}, userStats())
    }]);

    var scriptEl = document.createElement('script');
    scriptEl.id = 'metricsScrtipt';
    scriptEl.type = 'text/javascript';
    scriptEl.async = true;
    scriptEl.src = 'https://countly.openbazaar.org/sdk/web/countly.min.js';
    scriptEl.onload = function () {
      return window.Countly.init();
    };
    document.getElementsByTagName('head')[0].appendChild(scriptEl);
  }
  if (document.readyState === 'complete') {
    loadMetrics();
  } else {
    window.addEventListener('load', loadMetrics, false);
  }
}

function changeMetrics(bool) {
  if (bool) addMetrics();
  if (!bool && window.Countly) {
    metricsRestartNeeded = false;
    window.Countly.q.push(['opt_out']);
  }
  return _app2.default.localSettings.save({ shareMetrics: bool });
}

function showMetricsModal(opts) {
  var metricsModal = new _MetricsModal2.default(_extends({
    removeOnClose: true
  }, opts)).render().open();

  return metricsModal;
}

function recordEvent(key, segmentation) {
  if (window.Countly) {
    window.Countly.q.push(['add_event', {
      key: key,
      segmentation: segmentation
    }]);
  }
}

function startEvent(key) {
  if (window.Countly) window.Countly.q.push(['start_event', key]);
}

function endEvent(key, segmentation) {
  if (window.Countly) {
    window.Countly.q.push(['end_event', {
      key: key,
      segmentation: segmentation
    }]);
  }
}