'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.events = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.acceptingOrder = acceptingOrder;
exports.acceptOrder = acceptOrder;
exports.rejectingOrder = rejectingOrder;
exports.rejectOrder = rejectOrder;
exports.cancelingOrder = cancelingOrder;
exports.cancelOrder = cancelOrder;
exports.fulfillingOrder = fulfillingOrder;
exports.fulfillOrder = fulfillOrder;
exports.refundingOrder = refundingOrder;
exports.refundOrder = refundOrder;
exports.completingOrder = completingOrder;
exports.completeOrder = completeOrder;
exports.openingDispute = openingDispute;
exports.openDispute = openDispute;
exports.resolvingDispute = resolvingDispute;
exports.resolveDispute = resolveDispute;
exports.acceptingPayout = acceptingPayout;
exports.acceptPayout = acceptPayout;

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _backbone = require('backbone');

var _OrderFulfillment = require('../models/order/orderFulfillment/OrderFulfillment');

var _OrderFulfillment2 = _interopRequireDefault(_OrderFulfillment);

var _SimpleMessage = require('../views/modals/SimpleMessage');

var _OrderCompletion = require('../models/order/orderCompletion/OrderCompletion');

var _OrderCompletion2 = _interopRequireDefault(_OrderCompletion);

var _OrderDispute = require('../models/order/OrderDispute');

var _OrderDispute2 = _interopRequireDefault(_OrderDispute);

var _ResolveDispute = require('../models/order/ResolveDispute');

var _ResolveDispute2 = _interopRequireDefault(_ResolveDispute);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var events = _extends({}, _backbone.Events);

var acceptPosts = {};
var rejectPosts = {};
var cancelPosts = {};
var fulfillPosts = {};
var refundPosts = {};
var completePosts = {};
var openDisputePosts = {};
var resolvePosts = {};
var acceptPayoutPosts = {};

function confirmOrder(orderId) {
  var reject = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  if (!orderId) {
    throw new Error('Please provide an orderId');
  }

  var post = acceptPosts[orderId];

  if (reject) {
    post = rejectPosts[orderId];
  }

  if (!post) {
    post = _jquery2.default.post({
      url: _app2.default.getServerUrl('ob/orderconfirmation'),
      data: JSON.stringify({
        orderId: orderId,
        reject: reject
      }),
      dataType: 'json',
      contentType: 'application/json'
    }).always(function () {
      if (reject) {
        delete rejectPosts[orderId];
      } else {
        delete acceptPosts[orderId];
      }
    }).done(function () {
      events.trigger((reject ? 'reject' : 'accept') + 'OrderComplete', {
        id: orderId,
        xhr: post
      });
    }).fail(function (xhr) {
      events.trigger((reject ? 'reject' : 'accept') + 'OrderFail', {
        id: orderId,
        xhr: post
      });

      var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
      (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failed' + (reject ? 'Reject' : 'Accept') + 'Heading'), failReason);
    });

    if (reject) {
      rejectPosts[orderId] = post;
    } else {
      acceptPosts[orderId] = post;
    }

    events.trigger((reject ? 'rejecting' : 'accepting') + 'Order', {
      id: orderId,
      xhr: post
    });
  }

  return post;
}

exports.events = events;
function acceptingOrder(orderId) {
  return acceptPosts[orderId] || false;
}

function acceptOrder(orderId) {
  return confirmOrder(orderId);
}

function rejectingOrder(orderId) {
  return rejectPosts[orderId] || false;
}

function rejectOrder(orderId) {
  return confirmOrder(orderId, true);
}

function cancelingOrder(orderId) {
  return cancelPosts[orderId] || false;
}

function cancelOrder(orderId) {
  if (!orderId) {
    throw new Error('Please provide an orderId');
  }

  var post = cancelPosts[orderId];

  if (!post) {
    post = _jquery2.default.post({
      url: _app2.default.getServerUrl('ob/ordercancel'),
      data: JSON.stringify({
        orderId: orderId
      }),
      dataType: 'json',
      contentType: 'application/json'
    }).always(function () {
      delete cancelPosts[orderId];
    }).done(function () {
      events.trigger('cancelOrderComplete', {
        id: orderId,
        xhr: post
      });
    }).fail(function (xhr) {
      events.trigger('cancelOrderFail', {
        id: orderId,
        xhr: post
      });

      var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
      (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failedCancelHeading'), failReason);
    });

    cancelPosts[orderId] = post;
    events.trigger('cancelingOrder', {
      id: orderId,
      xhr: post
    });
  }

  return post;
}

function fulfillingOrder(orderId) {
  return fulfillPosts[orderId] || false;
}

function fulfillOrder() {
  var contractType = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'PHYSICAL_GOOD';
  var isLocalPickup = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  if (!data || !data.orderId) {
    throw new Error('An orderId must be provided with the data.');
  }

  var orderId = data.orderId;

  var post = fulfillPosts[orderId];

  if (!post) {
    var model = new _OrderFulfillment2.default(data, { contractType: contractType, isLocalPickup: isLocalPickup });
    post = model.save();

    if (!post) {
      Object.keys(model.validationError).forEach(function (errorKey) {
        throw new Error(errorKey + ': ' + model.validationError[errorKey][0]);
      });
    } else {
      post.always(function () {
        delete fulfillPosts[orderId];
      }).done(function () {
        events.trigger('fulfillOrderComplete', {
          id: orderId,
          xhr: post
        });
      }).fail(function (xhr) {
        events.trigger('fulfillOrderFail', {
          id: orderId,
          xhr: post
        });

        var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
        (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failedFulfillHeading'), failReason);
      });

      fulfillPosts[orderId] = post;
      events.trigger('fulfillingOrder', {
        id: orderId,
        xhr: post
      });
    }
  }

  return post;
}

function refundingOrder(orderId) {
  return refundPosts[orderId] || false;
}

function refundOrder(orderId) {
  if (!orderId) {
    throw new Error('Please provide an orderId');
  }

  var post = refundPosts[orderId];

  if (!post) {
    post = _jquery2.default.post({
      url: _app2.default.getServerUrl('ob/refund'),
      data: JSON.stringify({
        orderId: orderId
      }),
      dataType: 'json',
      contentType: 'application/json'
    }).always(function () {
      delete refundPosts[orderId];
    }).done(function () {
      events.trigger('refundOrderComplete', {
        id: orderId,
        xhr: post
      });
    }).fail(function (xhr) {
      events.trigger('refundOrderFail', {
        id: orderId,
        xhr: post
      });

      var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
      (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failedRefundHeading'), failReason);
    });

    refundPosts[orderId] = post;
    events.trigger('refundingOrder', {
      id: orderId,
      xhr: post
    });
  }

  return post;
}

/**
 * If the order with the given id is in the process of being completed, this method
 * will return an object containing the post xhr and the data that's being saved.
 */
function completingOrder(orderId) {
  return completePosts[orderId] || false;
}

function completeOrder(orderId) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (!orderId) {
    throw new Error('Please provide an orderId');
  }

  if (!completePosts[orderId]) {
    var model = new _OrderCompletion2.default(data);
    var save = model.save();

    if (!save) {
      Object.keys(model.validationError).forEach(function (errorKey) {
        throw new Error(errorKey + ': ' + model.validationError[errorKey][0]);
      });
    } else {
      save.always(function () {
        delete completePosts[orderId];
      }).done(function () {
        events.trigger('completeOrderComplete', {
          id: orderId,
          xhr: save
        });
      }).fail(function (xhr) {
        events.trigger('completeOrderFail', {
          id: orderId,
          xhr: save
        });

        var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
        (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failedCompleteHeading'), failReason);
      });

      completePosts[orderId] = {
        xhr: save,
        data: model.toJSON()
      };
    }

    events.trigger('completingOrder', {
      id: orderId,
      xhr: save
    });
  }

  return completePosts[orderId].xhr;
}

/**
 * If the order with the given id is in the process of a dispute being opened,
 * this method will return an object containing the post xhr and the data
 * that's being saved.
 */
function openingDispute(orderId) {
  return openDisputePosts[orderId] || false;
}

function openDispute(orderId) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (!orderId) {
    throw new Error('Please provide an orderId');
  }

  if (!openDisputePosts[orderId]) {
    var model = new _OrderDispute2.default(data);
    var save = model.save();

    if (!save) {
      Object.keys(model.validationError).forEach(function (errorKey) {
        throw new Error(errorKey + ': ' + model.validationError[errorKey][0]);
      });
    } else {
      save.always(function () {
        delete openDisputePosts[orderId];
      }).done(function () {
        events.trigger('openDisputeComplete', {
          id: orderId,
          xhr: save
        });
      }).fail(function (xhr) {
        events.trigger('openDisputeFail', {
          id: orderId,
          xhr: save
        });

        var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
        (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failedOpenDisputeHeading'), failReason);
      });

      openDisputePosts[orderId] = {
        xhr: save,
        data: model.toJSON()
      };
    }

    events.trigger('openingDisputeOrder', {
      id: orderId,
      xhr: save
    });
  }

  return openDisputePosts[orderId].xhr;
}

/**
 * If the order with the given id is in the process of its dispute being resolved,
 * this method will return an object containing the post xhr and the data that's
 * being saved.
 */
function resolvingDispute(orderId) {
  return resolvePosts[orderId] || false;
}

function resolveDispute(model) {
  if (!(model instanceof _ResolveDispute2.default)) {
    throw new Error('model must be provided as an instance of a ResolveDispute model.');
  }

  if (!model.id) {
    throw new Error('The model must have an id set.');
  }

  var orderId = model.id;

  if (!resolvePosts[orderId]) {
    var save = model.save();

    if (!save) {
      Object.keys(model.validationError).forEach(function (errorKey) {
        throw new Error(errorKey + ': ' + model.validationError[errorKey][0]);
      });
    } else {
      save.always(function () {
        delete resolvePosts[orderId];
      }).done(function () {
        events.trigger('resolveDisputeComplete', {
          id: orderId,
          xhr: save
        });
      }).fail(function (xhr) {
        events.trigger('resolveDisputeFail', {
          id: orderId,
          xhr: save
        });

        var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
        (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failedResolveHeading'), failReason);
      });

      resolvePosts[orderId] = {
        xhr: save,
        data: model.toJSON()
      };
    }

    events.trigger('resolvingDispute', {
      id: orderId,
      xhr: save
    });
  }

  return resolvePosts[orderId].xhr;
}

function acceptingPayout(orderId) {
  return acceptPayoutPosts[orderId] || false;
}

function acceptPayout(orderId) {
  if (!orderId) {
    throw new Error('Please provide an orderId');
  }

  var post = acceptPayoutPosts[orderId];

  if (!post) {
    post = _jquery2.default.post({
      url: _app2.default.getServerUrl('ob/releasefunds'),
      data: JSON.stringify({
        orderId: orderId
      }),
      dataType: 'json',
      contentType: 'application/json'
    }).always(function () {
      delete acceptPayoutPosts[orderId];
    }).done(function () {
      events.trigger('acceptPayoutComplete', {
        id: orderId,
        xhr: post
      });
    }).fail(function (xhr) {
      events.trigger('acceptPayoutFail', {
        id: orderId,
        xhr: post
      });

      var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
      (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('orderUtil.failedAcceptPayoutHeading'), failReason);
    });

    acceptPayoutPosts[orderId] = post;
    events.trigger('acceptingPayout', {
      id: orderId,
      xhr: post
    });
  }

  return post;
}