'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.events = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.isResyncAvailable = isResyncAvailable;
exports.default = resyncBlockchain;
exports.isResyncingBlockchain = isResyncingBlockchain;

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _serverConnect = require('./serverConnect');

var _SimpleMessage = require('../views/modals/SimpleMessage');

var _backbone = require('backbone');

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var events = _extends({}, _backbone.Events);

exports.events = events;


var server = (0, _serverConnect.getServer)();

// If you change this, be sure to change anywhere in the GUI you may have output how
// long its unavailable (e.g. Advanced Settings).
var resyncInactiveTime = 1000 * 60 * 60 * 1; // 1 hour

/**
 * Resync will be disabled if one was executed by this module less than the time specificed
 * in resyncInactiveTime. resyncBlockchain to remain flexible does not enforce this.
 * If you are exposing a resync function in the GUI, you probably want to disable it based
 * on this function.
 */
function __isResyncAvailable() {
  if (server) {
    var lastBlockchainResync = server.get('lastBlockchainResync');
    if (lastBlockchainResync && typeof lastBlockchainResync === 'number' && Date.now() - new Date(lastBlockchainResync).getTime() < resyncInactiveTime) {
      return false;
    }
  }

  return true;
}

var _isResyncAvailable = __isResyncAvailable();

function setResyncAvailable() {
  var bool = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

  if (typeof bool !== 'boolean') {
    throw new Error('Please provide bool as a boolean.');
  }

  if (bool !== _isResyncAvailable) {
    _isResyncAvailable = bool;
    events.trigger('changeResyncAvailable', bool);
  }
}

var lastResyncExpiresTimeout = null;

function setLastResyncExpiresTimeout() {
  clearTimeout(lastResyncExpiresTimeout);
  if (!server) return;

  var lastBlockchainResync = server.get('lastBlockchainResync');

  if (typeof lastBlockchainResync === 'number') {
    var fromNow = new Date(lastBlockchainResync).getTime() + resyncInactiveTime - Date.now();
    lastResyncExpiresTimeout = setTimeout(function () {
      setResyncAvailable(__isResyncAvailable(lastBlockchainResync));
    }, fromNow + 1000 * 60);
    // Giving a 1m buffer in case the timeout is a little fast
  }
}

function onChangeLastBlockchainResync(md, lastBlockchainResync) {
  setResyncAvailable(__isResyncAvailable(lastBlockchainResync));
  setLastResyncExpiresTimeout();
}

function onConnected(_server) {
  if (!_server) return;
  server = _server;
  setResyncAvailable(__isResyncAvailable(_server.get('lastBlockchainResync')));
  // for some reason this is not firing so the handler is being manually triggered in
  // resyncBlockchain
  // _server.on('change:lastBlockchainResync', () => onChangeLastBlockchainResync);
  setLastResyncExpiresTimeout();
}

if (server) onConnected(server);

_serverConnect.events.on('connected', function (conn) {
  return onConnected(conn.server);
});

_serverConnect.events.on('disconnected', function (conn) {
  server = null;
  clearTimeout(lastResyncExpiresTimeout);
  if (conn.server) {
    conn.server.off(null, onChangeLastBlockchainResync);
  }
});

function isResyncAvailable() {
  return _isResyncAvailable;
}

var resyncPost = void 0;

function resyncBlockchain() {
  if (resyncPost && resyncPost.state() === 'pending') return resyncPost;

  var _server = server;

  var post = _jquery2.default.post(_app2.default.getServerUrl('wallet/resyncblockchain')).fail(function (xhr) {
    if (xhr.statusText === 'abort') return;
    var failReason = xhr.responseJSON && xhr.responseJSON.reason || '';
    (0, _SimpleMessage.openSimpleMessage)(_app2.default.polyglot.t('resyncFail'), failReason);
    events.trigger('resyncFail', { xhr: post });
  }).done(function () {
    events.trigger('resyncComplete', { xhr: post });
    var lastBlockchainResync = new Date().getTime();

    if (_server) {
      _server.save({ lastBlockchainResync: lastBlockchainResync }).done(function () {
        // for some reason the change event isn't firing, so for now we'll
        // just manually trigger it
        if (server === _server) {
          onChangeLastBlockchainResync(_server, lastBlockchainResync);
        }
      });
    }
  });

  events.trigger('resyncing', { xhr: post });

  return post;
}

function isResyncingBlockchain() {
  return resyncPost && resyncPost.state() === 'pending';
}