'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _loadTemplate = require('../../utils/loadTemplate');

var _loadTemplate2 = _interopRequireDefault(_loadTemplate);

var _app = require('../../app');

var _app2 = _interopRequireDefault(_app);

var _serverConnect = require('../../utils/serverConnect');

var _SimpleMessage = require('../modals/SimpleMessage');

var _Moderators = require('../../collections/Moderators');

var _Moderators2 = _interopRequireDefault(_Moderators);

var _Profile = require('../../models/profile/Profile');

var _Profile2 = _interopRequireDefault(_Profile);

var _baseVw2 = require('../baseVw');

var _baseVw3 = _interopRequireDefault(_baseVw2);

var _ModeratorCard = require('./ModeratorCard');

var _ModeratorCard2 = _interopRequireDefault(_ModeratorCard);

var _ModeratorsStatus = require('./ModeratorsStatus');

var _ModeratorsStatus2 = _interopRequireDefault(_ModeratorsStatus);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _class = function (_baseVw) {
  _inherits(_class, _baseVw);

  /**
   * @param {string}  options.apiPath           - Current options are fetchprofiles and moderators.
   * @param {boolean} options.async             - Return profiles via websocket.
   * @param {boolean} options.useCache          - Use cached data for faster speed.
   * @param {array}   options.moderatorIDs      - list of moderators to retrieve. If none get all.
   * @param {array}   options.excludeIDs        - list of moderators to not use.
   * @param {string}  options.method            - POST or GET
   * @param {string}  options.include           - If apiPath is moderator, set to 'profile' or only
   *                                              the peerIDs of each moderator are returned.
   * @param {boolean} options.purchase          - If this is used in a purchase, pass this to the
   *                                              child moderator card views.
   * @param {boolean} options.singleSelect      - Allow only one moderator to be selected at a time.
   * @param {boolean} options.selectFirst       - Pre-select the first moderator.
   * @param {boolean} options.radioStyle        - Show the moderator cards with radio buttons.
   * @param {boolean} options.showInvalid       - Show invalid moderator cards.
   * @param {boolean} options.controlsOnInvalid - Show controls on invalid cards so they can be
   *                                              removed or otherwise acted on.
   * @param {string}  options.wrapperClasses    - Add classes to the card container.
   * @param {string}  options.fetchErrorTitle   - A title for the fetch error.
   * @param {string}  options.cardState         - The initial state for cards that are created.
   * @param {string}  options.notSelected       - Which not selected state to use on the mod cards.
   * @param {boolean} options.showLoadBtn       - Show the load more button in the status bar.
   * @param {boolean} options.showSpinner       - Show the spinner in the status bar
   * @param {boolean} options.showVerifiedOnly  - Show only verified moderators
   */

  function _class() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, _class);

    if (!options.fetchErrorTitle) {
      throw new Error('Please provide error text for the moderator fetch.');
    }

    var opts = _extends({
      className: 'moderatorsList',
      apiPath: 'fetchprofiles',
      async: true,
      useCache: true,
      moderatorIDs: [],
      excludeIDs: [],
      method: 'POST',
      include: '',
      purchase: false,
      singleSelect: false,
      selectFirst: false,
      radioStyle: false,
      controlsOnInvalid: false,
      cardState: 'unselected',
      notSelected: 'unselected',
      showLoadBtn: false,
      showSpinner: true
    }, options);

    if (!opts.apiPath || ['fetchprofiles', 'moderators'].indexOf(opts.apiPath) === -1) {
      throw new Error('The apiPath must be either fetchprofiles or moderators');
    }
    if (opts.apiPath === 'moderators') {
      if (opts.moderatorIDs.length) {
        throw new Error('If the apiPath is moderators, a list of IDs is not used.');
      }
    } else if (opts.apiPath === 'fetchprofiles' && opts.include) {
      throw new Error('If the apiPath is fetchprofiles, the include parameter is not used.');
    }
    if (typeof opts.async !== 'boolean') {
      throw new Error('The value of async must be a boolean');
    }
    if (!opts.fetchErrorTitle) {
      throw new Error('Please provide a title for the fetch error.');
    }

    if (opts.apiPath === 'moderators') {
      // this will fetch available moderators without POSTing a list of IDs.
      opts.include = 'profile';
      opts.method = 'GET';
    }

    var _this = _possibleConstructorReturn(this, (_class.__proto__ || Object.getPrototypeOf(_class)).call(this, opts));

    _this.options = opts;
    _this.excludeIDs = opts.excludeIDs;
    _this.unfetchedMods = [];
    _this.fetchingMods = [];
    _this.verifiedMods = [];
    _this.modFetches = [];
    _this.moderatorsCol = new _Moderators2.default();
    _this.listenTo(_this.moderatorsCol, 'add', function (model) {
      var modCard = _this.addMod(model);

      // if required, select the first  moderator
      if (opts.selectFirst && !_this.firstSelected && !_this.noneSelected) {
        var selectIt = true;
        // if only verified mods are shown, only select the first verified mod
        if (opts.showVerifiedOnly) selectIt = !!_app2.default.verifiedMods.get(model.get('peerID'));

        if (selectIt) {
          _this.firstSelected = true;
          modCard.changeSelectState('selected');
        }
      }
      _this.render();
    });
    _this.listenTo(_this.moderatorsCol, 'remove', function (md) {
      var removeIndex = _this.modCards.findIndex(function (card) {
        return card.model === md;
      });
      _this.modCards.splice(removeIndex, 1)[0].remove();
    });
    _this.modCards = [];

    // create a moderator status view. It should retain it's state between renders of this view.
    _this.moderatorsStatus = _this.createChild(_ModeratorsStatus2.default, {
      initialState: {
        mode: opts.method === 'GET' ? 'loaded' : '',
        showLoadBtn: opts.showLoadBtn,
        showSpinner: opts.showSpinner
      }
    });
    _this.listenTo(_this.moderatorsStatus, 'browseMore', function () {
      return _this.onBrowseMore();
    });

    // listen to the websocket for moderator data
    _this.serverSocket = (0, _serverConnect.getSocket)();
    return _this;
  }

  _createClass(_class, [{
    key: 'events',
    value: function events() {
      return {
        'click .js-showUnverified': 'clickShowUnverified'
      };
    }
  }, {
    key: 'clickShowUnverified',
    value: function clickShowUnverified() {
      this.togVerifiedShown(false);
      this.trigger('clickShowUnverified');
    }
  }, {
    key: 'onBrowseMore',
    value: function onBrowseMore() {
      this.getModeratorsByID();
    }
  }, {
    key: 'removeNotFetched',
    value: function removeNotFetched(ID) {
      this.unfetchedMods = this.unfetchedMods.filter(function (peerID) {
        return peerID !== ID;
      });
      this.checkNotFetched();
    }
  }, {
    key: 'processMod',
    value: function processMod(data) {
      // Don't add profiles that are not moderators unless showInvalid is true. The ID list may have
      // peerIDs that are out of date, and are no longer moderators.
      var validMod = data.moderator && data.moderatorInfo;
      // if the moderator has an invalid currency, remove them from the list
      var buyerCur = _app2.default.serverConfig.cryptoCurrency;
      var modCurs = data.moderatorInfo && data.moderatorInfo.acceptedCurrencies || [];
      var validCur = modCurs.includes(buyerCur);

      if (!!validMod && validCur || this.options.showInvalid) {
        this.moderatorsCol.add(new _Profile2.default(data, { parse: true }));
        this.removeNotFetched(data.peerID);
      } else {
        // remove the invalid moderator from the notFetched list
        this.removeNotFetched(data.peerID);
      }
    }
  }, {
    key: 'getModeratorsByID',
    value: function getModeratorsByID(opts) {
      var _this2 = this;

      var op = _extends({}, this.options, opts);

      if (!Array.isArray(op.moderatorIDs)) {
        throw new Error('Please provide the list of moderators as an array.');
      }

      // don't get any that have already been added or excluded, or the user's own id.
      var excluded = [].concat(_toConsumableArray(this.allIDs), _toConsumableArray(this.excludeIDs), [_app2.default.profile.id]);
      var IDs = _underscore2.default.without(op.moderatorIDs, excluded);
      var includeString = op.include ? '&include=' + op.include : '';
      var urlString = 'ob/' + op.apiPath + '?async=' + op.async + includeString + '&usecache=' + op.useCache;
      var url = _app2.default.getServerUrl(urlString);

      this.unfetchedMods = IDs;
      this.fetchingMods = IDs;
      this.verifiedMods = _app2.default.verifiedMods.matched(IDs);

      this.setState({
        noValidModerators: false,
        noValidVerifiedModerators: !this.verifiedMods.length && this.fetchingMods.length
      });

      // Either a list of IDs can be posted, or any available moderators can be retrieved with GET
      if (IDs.length || op.method === 'GET') {
        this.moderatorsStatus.setState({
          hidden: false,
          loaded: this.modCount,
          total: IDs.length ? IDs.length : this.modCount,
          showSpinner: op.showSpinner //unhides the spinner if it's been hidden by the timer
        });

        var fetch = _jquery2.default.ajax({
          url: url,
          data: JSON.stringify(IDs),
          method: op.method
        }).done(function (data) {
          if (op.async) {
            var socketID = data.id;
            if (_this2.serverSocket) {
              _this2.listenTo(_this2.serverSocket, 'message', function (event) {
                var eventData = event.jsonData;
                if (eventData.error) {
                  // errors don't have a message id, check to see if the peerID matches
                  if (IDs.includes(eventData.peerId)) {
                    // provide the expected capitalization of peerID
                    eventData.peerID = eventData.peerId;
                    delete eventData.peerId;
                    _this2.processMod(eventData);
                  }
                } else if (eventData.id === socketID && !excluded.includes(eventData.peerId)) {
                  _this2.processMod(eventData.profile);
                }
              });
            } else {
              throw new Error('There is no connection to the server to listen to.');
            }
          } else {
            data.forEach(function (mod) {
              if (!excluded.includes(mod.peerId)) _this2.processMod(mod.profile);
            });
            _this2.unfetchedMods = [];
            _this2.checkNotFetched();
            if (!data.length) _this2.trigger('noModsFound', { guids: IDs });
          }
        }).fail(function (xhr) {
          if (xhr.statusText === 'abort') return;
          var failReason = xhr.responseJSON ? '\n\n' + xhr.responseJSON.reason : '';
          var msg = '' + op.fetchErrorMsg + failReason;
          (0, _SimpleMessage.openSimpleMessage)(op.fetchErrorTitle, msg);
        });
        this.modFetches.push(fetch);
      }
    }
  }, {
    key: 'removeModeratorsByID',
    value: function removeModeratorsByID(IDs) {
      var _this3 = this;

      if (!IDs) {
        throw new Error('You must provide the ID or IDs to remove.');
      }
      // collect the models so they can be returned to the caller
      var removed = [];
      IDs.forEach(function (id) {
        removed.push(_this3.moderatorsCol.get(id));
      });
      this.moderatorsCol.remove(IDs);
      return removed;
    }
  }, {
    key: 'checkNotFetched',
    value: function checkNotFetched() {
      var nfYet = this.unfetchedMods.length;
      if (nfYet === 0 && this.fetchingMods.length) {
        // all ids have been fetched and ids existed to fetch
        this.moderatorsStatus.setState({
          hidden: true
        });
        // check if there are mods that loaded but none were valid
        if (!this.moderatorsCol.length && this.fetchingMods.length) {
          this.trigger('noValidModerators');
          this.setState({ noValidModerators: true });
        }
        // check if no valid verified mods where loaded
        if (this.verifiedMods.length && !this.modCount) {
          this.trigger('noValidVerifiedModerators');
          this.setState({ noValidVerifiedModerators: true });
        }
      } else {
        // either ids are still fetching, or this is an open fetch with no set ids
        this.moderatorsStatus.setState({
          loaded: this.fetchingMods.length - nfYet, // not shown if open fetch
          total: this.fetchingMods.length ? this.fetchingMods.length : this.modCount
        });
      }
    }
  }, {
    key: 'addMod',
    value: function addMod(model) {
      var _this4 = this;

      if (!model || !(model instanceof _Profile2.default)) {
        throw new Error('Please provide a moderator model.');
      }

      var modCard = this.createChild(_ModeratorCard2.default, {
        model: model,
        purchase: this.options.purchase,
        notSelected: this.options.notSelected,
        cardState: this.options.cardState,
        radioStyle: this.options.radioStyle,
        controlsOnInvalid: this.options.controlsOnInvalid
      });
      this.listenTo(modCard, 'modSelectChange', function (data) {
        if (data.selected) {
          _this4.noneSelected = false;
          // if only one moderator should be selected, deselect the other moderators
          if (_this4.options.singleSelect) _this4.deselectOthers(data.guid);
          _this4.trigger('cardSelect');
        }
      });
      // add verified mods to the beginning
      if (_app2.default.verifiedMods.get(model.get('peerID'))) {
        var firstUnverifiedIndex = this.modCards.findIndex(function (card) {
          return !_app2.default.verifiedMods.get(card.model.get('peerID'));
        });
        var insertAtIndex = firstUnverifiedIndex < 0 ? 0 : firstUnverifiedIndex;
        this.modCards.splice(insertAtIndex, 0, modCard);
      } else {
        this.modCards.push(modCard);
      }
      return modCard;
    }
  }, {
    key: 'deselectMod',
    value: function deselectMod(guid) {
      if (!guid) throw new Error('You must provide a guid.');

      var mod = this.modCards.filter(function (card) {
        return card.model.get('peerID') === guid;
      });
      if (mod.length) mod[0].changeSelectState(this.options.notSelected);
    }
  }, {
    key: 'deselectOthers',
    value: function deselectOthers() {
      var _this5 = this;

      var guid = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

      this.modCards.forEach(function (card) {
        if (card.model.get('peerID') !== guid) {
          card.changeSelectState(_this5.options.notSelected);
        }
      });
      this.noneSelected = !guid;
    }
  }, {
    key: 'togVerifiedShown',
    value: function togVerifiedShown(bool) {
      this.setState({ showVerifiedOnly: bool });
    }
  }, {
    key: 'remove',
    value: function remove() {
      this.modFetches.forEach(function (fetch) {
        return fetch.abort();
      });
      _get(_class.prototype.__proto__ || Object.getPrototypeOf(_class.prototype), 'remove', this).call(this);
    }
  }, {
    key: 'render',
    value: function render() {
      var _this6 = this;

      (0, _loadTemplate2.default)('components/moderators.html', function (t) {
        _this6.$el.html(t(_extends({
          wrapperClasses: _this6.options.wrapperClasses,
          showVerifiedOnly: _this6.options.showVerifiedOnly,
          placeholder: !_this6.modCards.length,
          purchase: _this6.options.purchase
        }, _this6.getState())));

        _get(_class.prototype.__proto__ || Object.getPrototypeOf(_class.prototype), 'render', _this6).call(_this6);
        _this6.modCards.forEach(function (mod) {
          mod.delegateEvents();
          _this6.getCachedEl('.js-moderatorsWrapper').append(mod.render().$el);
        });

        _this6.moderatorsStatus.delegateEvents();
        _this6.getCachedEl('.js-statusWrapper').append(_this6.moderatorsStatus.render().$el);
      });

      return this;
    }
  }, {
    key: 'excludeIDs',
    get: function get() {
      return this._excludeIDs;
    },
    set: function set(IDs) {
      this._excludeIDs = IDs;
    }
  }, {
    key: 'modCount',
    get: function get() {
      // return the number of visible cards. The collection may have unshown invalid moderators.
      return this.modCards.length;
    }
  }, {
    key: 'allIDs',
    get: function get() {
      return this.moderatorsCol.pluck('peerID');
    }
  }, {
    key: 'selectedIDs',
    get: function get() {
      var IDs = [];
      this.modCards.forEach(function (mod) {
        if (mod.cardState === 'selected') {
          IDs.push(mod.model.id);
        }
      });
      return IDs;
    }
  }, {
    key: 'unselectedIDs',
    get: function get() {
      var IDs = [];
      this.modCards.forEach(function (mod) {
        if (mod.cardState !== 'selected') {
          IDs.push(mod.model.id);
        }
      });
      return IDs;
    }
  }, {
    key: 'noneSelected',
    get: function get() {
      return this._noneSelected;
    },
    set: function set(bool) {
      this._noneSelected = bool;
    }
  }]);

  return _class;
}(_baseVw3.default);

exports.default = _class;